Module background

Module background 

Chat background types.

Structs

BackgroundFillFreeformGradient
A background filled with a freeform gradient that rotates after every message.
BackgroundFillGradient
A background filled with a two-colour gradient.
BackgroundFillSolid
A background filled with a single colour.
BackgroundTypeChatTheme
A background taken from one of the default chat themes.
BackgroundTypeFill
A background automatically filled based on colours.
BackgroundTypePattern
A background that is a PNG or TGV pattern filled with a colour.
BackgroundTypeWallpaper
A background that is a wallpaper image in JPEG format.
ChatBackground
A chat background.

Enums

BackgroundFill
How a chat background is filled with colour.
BackgroundType
The type of a chat background.