#[non_exhaustive]pub struct BackgroundFillFreeformGradient {
pub colors: Vec<u32>,
}Expand description
A background filled with a freeform gradient that rotates after every message.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.colors: Vec<u32>Three or four base colours used to generate the gradient, in RGB24 format.