#[non_exhaustive]pub struct BackgroundTypeChatTheme {
pub theme_name: String,
}Expand description
A background taken from one of the default chat themes.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.theme_name: StringName of the chat theme, which is usually an emoji.