#[non_exhaustive]pub struct BackgroundTypePattern {
pub document: Document,
pub fill: BackgroundFill,
pub intensity: u8,
pub is_inverted: Option<bool>,
pub is_moving: Option<bool>,
}Expand description
A background that is a PNG or TGV pattern filled with a colour.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.document: DocumentDocument with the pattern.
fill: BackgroundFillThe background fill used to combine with the pattern.
intensity: u8Intensity of the pattern when it is shown above the filled background, as a percentage (0–100).
is_inverted: Option<bool>true if the background fill must be applied only to the pattern itself.
All other pixels are black in this case.
is_moving: Option<bool>true if the background moves slightly when the device is tilted.