#[non_exhaustive]pub struct BackgroundTypeWallpaper {
pub document: Document,
pub dark_theme_dimming: u8,
pub is_blurred: Option<bool>,
pub is_moving: Option<bool>,
}Expand description
A background that is a wallpaper image in JPEG format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.document: DocumentDocument with the wallpaper.
dark_theme_dimming: u8Dimming of the background in dark themes, as a percentage (0–100).
is_blurred: Option<bool>true if the wallpaper is downscaled to fit in a 450×450 square and
then box-blurred with a radius of 12.
is_moving: Option<bool>true if the background moves slightly when the device is tilted.