pub struct ChatInviteLink {
pub invite_link: String,
pub creator: User,
pub creates_join_request: bool,
pub is_primary: bool,
pub is_revoked: bool,
pub name: Option<String>,
pub expire_date: Option<i64>,
pub member_limit: Option<u32>,
pub pending_join_request_count: Option<u32>,
pub subscription_period: Option<u32>,
pub subscription_price: Option<u32>,
}Expand description
Invite link for a chat.
Fields
invite_link: StringThe invite link.
creator: UserCreator of the link.
creates_join_request: booltrue if users joining the chat via the link need to be approved by chat admins.
is_primary: booltrue if the link is primary.
is_revoked: booltrue if the link is revoked.
name: Option<String>Invite link name.
expire_date: Option<i64>Point in time (Unix) when the link will expire or has been expired.
member_limit: Option<u32>Maximum number of users that can be members of the chat simultaneously.
pending_join_request_count: Option<u32>Number of pending join requests created using this link.
subscription_period: Option<u32>Number of seconds the subscription created by this link will be active.
subscription_price: Option<u32>Number of Telegram Stars a user must pay for a subscription.