pub struct Location {
pub latitude: f64,
pub longitude: f64,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<u32>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
}Expand description
Geographic point on the map.
Fields
latitude: f64Latitude as defined by the sender.
longitude: f64Longitude as defined by the sender.
horizontal_accuracy: Option<f64>Radius of uncertainty for the location, in metres (0–1500).
live_period: Option<u32>Time relative to the message sending date, during which the location can be updated; in seconds.
heading: Option<u16>Direction of movement in degrees (1–360).
proximity_alert_radius: Option<u32>Maximum distance in metres for proximity alerts.