Module checklist

Module checklist 

Checklist content type and related service messages.

Structs

Checklist
A checklist message content type.
ChecklistTask
A single task in a checklist.
ChecklistTasksAdded
Service message: new tasks were added to a checklist.
ChecklistTasksDone
Service message: tasks in a checklist were marked as done or not done.
InputChecklist
A checklist to send or create.
InputChecklistTask
A task to add when creating or editing a checklist.