pub struct Checklist {
pub title: String,
pub title_entities: Option<Vec<MessageEntity>>,
pub tasks: Vec<ChecklistTask>,
pub others_can_add_tasks: Option<bool>,
pub others_can_mark_tasks_as_done: Option<bool>,
}Expand description
A checklist message content type.
Fields
title: StringTitle of the checklist.
title_entities: Option<Vec<MessageEntity>>Special entities in the checklist title.
tasks: Vec<ChecklistTask>List of tasks in the checklist.
others_can_add_tasks: Option<bool>true if users other than the creator can add tasks.
others_can_mark_tasks_as_done: Option<bool>true if users other than the creator can mark tasks as done or not done.