pub struct ChecklistTasksDone {
pub checklist_message: Option<Box<Message>>,
pub marked_as_done_task_ids: Option<Vec<i64>>,
pub marked_as_not_done_task_ids: Option<Vec<i64>>,
}Expand description
Service message: tasks in a checklist were marked as done or not done.
Fields
checklist_message: Option<Box<Message>>Message containing the checklist whose tasks were updated.
Boxed to break the recursive Message → ChecklistTasksDone → Message cycle.
Will not contain reply_to_message even if the message itself is a reply.
marked_as_done_task_ids: Option<Vec<i64>>Identifiers of the tasks that were marked as done.
marked_as_not_done_task_ids: Option<Vec<i64>>Identifiers of the tasks that were marked as not done.