pub struct InputChecklist {
pub title: String,
pub parse_mode: Option<ParseMode>,
pub title_entities: Option<Vec<MessageEntity>>,
pub tasks: Vec<InputChecklistTask>,
pub others_can_add_tasks: Option<bool>,
pub others_can_mark_tasks_as_done: Option<bool>,
}Expand description
A checklist to send or create.
Fields
title: StringTitle of the checklist (1–255 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for entities in the title.
title_entities: Option<Vec<MessageEntity>>Special entities in the title; alternative to parse_mode.
tasks: Vec<InputChecklistTask>List of 1–30 tasks in the checklist.
others_can_add_tasks: Option<bool>Pass true if other users can add tasks to the checklist.
others_can_mark_tasks_as_done: Option<bool>Pass true if other users can mark tasks as done or not done.