Module community

Module community 

Community (linked chats) types.

Structs

Community
A community (a group of chats).
CommunityChatAdded
A service message about a chat being added to a community.
CommunityChatRemoved
A service message about a chat being removed from a community.