DirectMessagePriceChanged

Struct DirectMessagePriceChanged 

pub struct DirectMessagePriceChanged {
    pub are_direct_messages_enabled: bool,
    pub direct_message_star_count: Option<i64>,
}
Service message: the price for paid messages in a direct messages chat changed.

Fields

are_direct_messages_enabled: bool

true if direct messages are enabled for the channel chat.

direct_message_star_count: Option<i64>

The new number of Telegram Stars users must pay per direct message.

Does not apply to users exempted by administrators. Defaults to 0.