pub struct Audio {
pub file_id: String,
pub file_unique_id: String,
pub duration: u32,
pub performer: Option<String>,
pub title: Option<String>,
pub file_name: Option<String>,
pub mime_type: Option<String>,
pub file_size: Option<u64>,
pub thumbnail: Option<PhotoSize>,
}Expand description
Audio file to be treated as music.
Fields
file_id: StringTelegram file identifier.
file_unique_id: StringUnique file identifier, stable across bots and time.
duration: u32Duration of the audio in seconds.
performer: Option<String>Performer of the audio as defined by the sender or audio tags.
title: Option<String>Title of the audio as defined by the sender or audio tags.
file_name: Option<String>Original filename as defined by the sender.
mime_type: Option<String>MIME type of the audio.
file_size: Option<u64>File size in bytes.
thumbnail: Option<PhotoSize>Thumbnail of the album cover.