pub struct InputMediaLivePhoto {
pub media: String,
pub photo: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub has_spoiler: Option<bool>,
}Expand description
A live photo to be sent as part of a media group or to replace an existing media message.
Sending live photos by URL is currently unsupported — use file_id or attach://<n>.
Fields
media: StringVideo of the live photo: file_id or "attach://<n>".
photo: StringThe static photo: file_id or "attach://<n>".
caption: Option<String>Caption (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption.
show_caption_above_media: Option<bool>true if the caption must be shown above the media.
has_spoiler: Option<bool>true if the live photo needs a spoiler animation.