pub struct InputMediaVideo {Show 13 fields
pub media: String,
pub thumbnail: Option<String>,
pub cover: Option<String>,
pub start_timestamp: Option<i64>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub width: Option<u32>,
pub height: Option<u32>,
pub duration: Option<u32>,
pub supports_streaming: Option<bool>,
pub has_spoiler: Option<bool>,
}Expand description
A video to include in a media group or replace an existing media message.
Fields
media: StringFile to send: file_id, HTTP URL, or "attach://<n>".
thumbnail: Option<String>Thumbnail: file_id or "attach://<n>".
cover: Option<String>Cover image: file_id, HTTP URL, or "attach://<n>".
start_timestamp: Option<i64>Start timestamp for the video in the message.
caption: Option<String>Caption (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption.
show_caption_above_media: Option<bool>true if the caption must be shown above the media.
width: Option<u32>Video width in pixels.
height: Option<u32>Video height in pixels.
duration: Option<u32>Video duration in seconds.
supports_streaming: Option<bool>true if the uploaded video is suitable for streaming.
has_spoiler: Option<bool>true if the video needs a spoiler animation.