pub struct LivePhoto {
pub photo: Option<Vec<PhotoSize>>,
pub file_id: String,
pub file_unique_id: String,
pub width: u32,
pub height: u32,
pub duration: u32,
pub mime_type: Option<String>,
pub file_size: Option<u64>,
}Expand description
A photo with a short video (live photo).
Fields
photo: Option<Vec<PhotoSize>>Available sizes of the corresponding static photo.
file_id: StringIdentifier for the video file.
file_unique_id: StringUnique identifier for the video file, stable across bots and time.
width: u32Video width as defined by the sender.
height: u32Video height as defined by the sender.
duration: u32Duration of the video in seconds.
mime_type: Option<String>MIME type of the file as defined by the sender.
file_size: Option<u64>File size in bytes.