#[non_exhaustive]pub struct ForumTopicEdited {
pub name: Option<String>,
pub icon_custom_emoji_id: Option<String>,
}Expand description
Service message: a forum topic was edited.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>New name of the topic, if it was changed.
icon_custom_emoji_id: Option<String>New icon emoji identifier, if it was changed. An empty string means the custom icon was removed.