#[non_exhaustive]pub struct Game {
pub title: String,
pub description: String,
pub photo: Vec<PhotoSize>,
pub text: Option<String>,
pub text_entities: Option<Vec<MessageEntity>>,
pub animation: Option<Animation>,
}Expand description
A game to be played in a Telegram chat.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: StringTitle of the game.
description: StringDescription of the game.
photo: Vec<PhotoSize>Photo displayed in the game message in chats.
text: Option<String>Brief description of the game, or high scores included in the message.
Set by calling setGameScore,
or edited via
editMessageText.
0–4096 characters.
text_entities: Option<Vec<MessageEntity>>Special entities that appear in text.
animation: Option<Animation>Animation displayed in the game message in chats.