UniqueGift

Struct UniqueGift 

pub struct UniqueGift {
    pub gift_id: String,
    pub base_name: String,
    pub name: String,
    pub number: u32,
    pub model: UniqueGiftModel,
    pub symbol: UniqueGiftSymbol,
    pub backdrop: UniqueGiftBackdrop,
    pub is_premium: Option<bool>,
    pub is_burned: Option<bool>,
    pub is_from_blockchain: Option<bool>,
    pub colors: Option<UniqueGiftColors>,
    pub publisher_chat: Option<Chat>,
}
A unique gift upgraded from a regular gift.

Fields

gift_id: String

Identifier of the regular gift from which this was upgraded.

base_name: String

Human-readable name of the original regular gift.

name: String

Unique name usable in https://t.me/nft/... links and story areas.

number: u32

Unique number among gifts upgraded from the same regular gift.

model: UniqueGiftModel

Model of the gift.

symbol: UniqueGiftSymbol

Symbol of the gift.

backdrop: UniqueGiftBackdrop

Backdrop of the gift.

is_premium: Option<bool>

true if the original regular gift was exclusively purchaseable by Premium subscribers.

is_burned: Option<bool>

true if the gift was used to craft another gift and is no longer available.

is_from_blockchain: Option<bool>

true if the gift is from the TON blockchain and cannot be resold or transferred.

colors: Option<UniqueGiftColors>

Color scheme for the owner’s chat name, replies, and link previews.

publisher_chat: Option<Chat>

Information about the chat that published the gift.