#[non_exhaustive]pub struct UniqueGiftInfo {
pub gift: UniqueGift,
pub origin: String,
pub last_resale_currency: Option<String>,
pub last_resale_amount: Option<i64>,
pub owned_gift_id: Option<String>,
pub transfer_star_count: Option<i64>,
pub next_transfer_date: Option<i64>,
}Expand description
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.gift: UniqueGiftInformation about the gift.
origin: StringOrigin of the gift.
One of "upgrade", "transfer", or "resale".
last_resale_currency: Option<String>Currency of the last resale, if the gift was bought from another user.
last_resale_amount: Option<i64>Amount paid at the last resale, in the smallest unit of the currency.
owned_gift_id: Option<String>Identifier of the received gift for the bot.
transfer_star_count: Option<i64>Number of Telegram Stars that must be paid to transfer the gift.
next_transfer_date: Option<i64>Point in time when the gift can be transferred, as a Unix timestamp.