pub struct UniqueGiftSymbol {
pub name: String,
pub sticker: Sticker,
pub rarity_per_mille: u32,
}Expand description
Symbol shown on the pattern of a unique gift.
Fields
name: StringName of the symbol.
sticker: StickerThe sticker that represents this symbol.
rarity_per_mille: u32Number of unique gifts receiving this symbol per 1000 upgrades.