#[non_exhaustive]pub struct GiveawayCompleted {
pub winner_count: u32,
pub unclaimed_prize_count: Option<u32>,
pub giveaway_message: Option<Box<Message>>,
pub is_star_giveaway: Option<bool>,
}Expand description
Service message: a giveaway without public winners has completed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.winner_count: u32Number of winners in the giveaway.
unclaimed_prize_count: Option<u32>Number of undistributed prizes.
giveaway_message: Option<Box<Message>>The message with the giveaway that was completed.
Boxed because Message transitively contains this type, and an
unboxed cycle would make the struct infinitely sized.
is_star_giveaway: Option<bool>true if the giveaway is a Telegram Star giveaway.