#[non_exhaustive]pub struct GiveawayWinners {
pub chat: Chat,
pub giveaway_message_id: i64,
pub winners_selection_date: i64,
pub winner_count: u32,
pub winners: Vec<User>,
pub additional_chat_count: Option<u32>,
pub prize_star_count: Option<i64>,
pub premium_subscription_month_count: Option<u32>,
pub unclaimed_prize_count: Option<u32>,
pub only_new_members: Option<bool>,
pub was_refunded: Option<bool>,
pub prize_description: Option<String>,
}Expand description
Service message: giveaway winners were selected.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.chat: ChatThe chat that created the giveaway.
giveaway_message_id: i64Identifier of the message with the giveaway in the chat.
winners_selection_date: i64Point in time when winners were selected, as a Unix timestamp.
winner_count: u32Total number of winners.
winners: Vec<User>The users who won the giveaway, up to 100.
additional_chat_count: Option<u32>Number of other chats the user had to join to take part.
prize_star_count: Option<i64>Number of Telegram Stars split among winners; Star giveaways only.
Number of months the won Premium subscription is active for.
unclaimed_prize_count: Option<u32>Number of undistributed prizes.
only_new_members: Option<bool>true if only users who joined after the giveaway started were eligible.
was_refunded: Option<bool>true if the giveaway was cancelled because the payment was refunded.
prize_description: Option<String>Description of additional giveaway prizes.