pub struct InlineQueryResultCachedAudio {
pub id: String,
pub audio_file_id: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
An audio file from a previously uploaded Telegram file.
Fields
id: StringUnique identifier for this result (1–64 bytes).
audio_file_id: StringA valid Telegram file_id of the audio file.
caption: Option<String>Caption of the audio (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption; alternative to parse_mode.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the audio.