pub struct InlineQueryResultCachedDocument {
pub id: String,
pub title: String,
pub document_file_id: String,
pub description: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
A document result using a previously uploaded Telegram file_id.
Fields
id: StringUnique identifier for this result (1–64 bytes).
title: StringA valid Telegram file_id of the cached media.
document_file_id: StringA valid Telegram file_id of the cached media.
description: Option<String>Short description of the result.
caption: Option<String>Caption of the media (0–1024 characters).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the media.