pub struct InlineQueryResultCachedGif {
pub id: String,
pub gif_file_id: String,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
An animated GIF from a previously uploaded Telegram file.
Fields
id: StringUnique identifier for this result (1–64 bytes).
gif_file_id: StringA valid Telegram file_id of the GIF.
title: Option<String>Title for the result.
caption: Option<String>Caption of the GIF (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption; alternative to parse_mode.
show_caption_above_media: Option<bool>true if the caption must be shown above the GIF.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the GIF.