pub struct InlineQueryResultGif {Show 14 fields
pub id: String,
pub gif_url: String,
pub thumbnail_url: String,
pub gif_width: Option<u32>,
pub gif_height: Option<u32>,
pub gif_duration: Option<u32>,
pub thumbnail_mime_type: Option<String>,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
A link to an animated GIF file (max 1 MB).
Fields
id: StringUnique identifier for this result (1–64 bytes).
gif_url: StringA valid URL for the GIF file.
thumbnail_url: StringURL of the static or animated thumbnail for the result.
gif_width: Option<u32>Width of the GIF in pixels.
gif_height: Option<u32>Height of the GIF in pixels.
gif_duration: Option<u32>Duration of the GIF in seconds.
thumbnail_mime_type: Option<String>MIME type of the thumbnail (image/jpeg, image/gif, or video/mp4).
title: Option<String>Title for the result.
caption: Option<String>Caption of the GIF (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption; alternative to parse_mode.
show_caption_above_media: Option<bool>true if the caption must be shown above the GIF.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the GIF.