InlineQueryResultLocation

Struct InlineQueryResultLocation 

pub struct InlineQueryResultLocation {
Show 13 fields pub id: String, pub latitude: f64, pub longitude: f64, pub title: String, pub horizontal_accuracy: Option<f64>, pub live_period: Option<u32>, pub heading: Option<u16>, pub proximity_alert_radius: Option<u32>, pub reply_markup: Option<InlineKeyboardMarkup>, pub input_message_content: Option<InputMessageContent>, pub thumbnail_url: Option<String>, pub thumbnail_width: Option<u32>, pub thumbnail_height: Option<u32>,
}
A location result in an inline query.

Fields

id: String

Unique identifier for this result (1–64 bytes).

latitude: f64

Location latitude in degrees.

longitude: f64

Location longitude in degrees.

title: String

Location title.

horizontal_accuracy: Option<f64>

Radius of uncertainty for the location, in metres (0–1500).

live_period: Option<u32>

Period in seconds during which the location can be updated (60–86400).

heading: Option<u16>

Direction of movement in degrees (1–360) for live locations.

proximity_alert_radius: Option<u32>

Maximum distance in metres for proximity alerts.

reply_markup: Option<InlineKeyboardMarkup>

Inline keyboard attached to the message.

input_message_content: Option<InputMessageContent>

Content of the message to be sent instead of the media.

thumbnail_url: Option<String>

URL of the thumbnail for the result.

thumbnail_width: Option<u32>

Thumbnail width in pixels.

thumbnail_height: Option<u32>

Thumbnail height in pixels.