pub struct InlineQueryResultPhoto {Show 13 fields
pub id: String,
pub photo_url: String,
pub thumbnail_url: String,
pub photo_width: Option<u32>,
pub photo_height: Option<u32>,
pub title: Option<String>,
pub description: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
A link to a photo (JPEG, max 5 MB). A photo result in an inline query.
Fields
id: StringUnique identifier for this result (1–64 bytes).
photo_url: StringA valid URL of the photo.
thumbnail_url: StringURL of the thumbnail for the photo.
photo_width: Option<u32>Photo width in pixels.
photo_height: Option<u32>Photo height in pixels.
title: Option<String>Title for the result.
description: Option<String>Short description of the result.
caption: Option<String>Caption of the photo (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption; alternative to parse_mode.
show_caption_above_media: Option<bool>true if the caption must be shown above the photo.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the photo.