pub struct InlineQueryResultVideo {Show 15 fields
pub id: String,
pub video_url: String,
pub mime_type: String,
pub thumbnail_url: String,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub caption_entities: Option<Vec<MessageEntity>>,
pub show_caption_above_media: Option<bool>,
pub video_width: Option<u32>,
pub video_height: Option<u32>,
pub video_duration: Option<u32>,
pub description: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
}Expand description
A link to a video file (text/html or video/mp4).
Fields
id: StringUnique identifier for this result (1–64 bytes).
video_url: StringA valid URL for the video file.
mime_type: StringMIME type of the video (text/html or video/mp4).
thumbnail_url: StringURL of the thumbnail for the video.
title: StringTitle for the result.
caption: Option<String>Caption of the video (0–1024 characters after entities parsing).
parse_mode: Option<ParseMode>Parse mode for the caption.
caption_entities: Option<Vec<MessageEntity>>Special entities in the caption; alternative to parse_mode.
show_caption_above_media: Option<bool>true if the caption must be shown above the video.
video_width: Option<u32>Video width in pixels.
video_height: Option<u32>Video height in pixels.
video_duration: Option<u32>Video duration in seconds.
description: Option<String>Short description of the result.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the video.