pub struct InputLocationMessageContent {
pub latitude: f64,
pub longitude: f64,
pub horizontal_accuracy: Option<f64>,
pub live_period: Option<u32>,
pub heading: Option<u16>,
pub proximity_alert_radius: Option<u32>,
}Expand description
Live location content for an inline query result.
Fields
latitude: f64Latitude in degrees.
longitude: f64Longitude in degrees.
horizontal_accuracy: Option<f64>Radius of uncertainty for the location, in metres (0–1500).
live_period: Option<u32>Period in seconds during which the location can be updated (60–86400).
heading: Option<u16>Direction of movement in degrees (1–360).
proximity_alert_radius: Option<u32>Maximum distance for proximity alerts in metres.