#[non_exhaustive]pub struct PreparedInlineMessage {
pub id: String,
pub expiration_date: i64,
}Expand description
An inline message prepared for sending by a Mini App.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringUnique identifier of the prepared message.
expiration_date: i64Point in time when the prepared message can no longer be used, as a Unix timestamp.