Module keyboard

Module keyboard 

Keyboard and markup types.

Structs

CopyTextButton
Represents a button that copies text to clipboard.
ForceReply
Forces a reply from the user.
InlineKeyboardButton
One button in an inline keyboard.
InlineKeyboardMarkup
An inline keyboard attached to a message.
KeyboardButton
One button in a reply keyboard.
KeyboardButtonPollType
The type of poll requested via a keyboard button.
KeyboardButtonRequestChat
Defines criteria for selecting a chat via a keyboard button.
KeyboardButtonRequestManagedBot
Defines parameters for requesting the creation of a managed bot.
KeyboardButtonRequestUsers
Defines criteria for selecting users via a keyboard button.
LoginUrl
Parameters for a Login URL button.
PreparedKeyboardButton
A keyboard button prepared for use by a Mini App.
ReplyKeyboardMarkup
Custom keyboard shown to the message recipient.
ReplyKeyboardRemove
Instructs clients to remove the reply keyboard.
SwitchInlineQueryChosenChat
Parameters for inline query routing to a specific type of chat.

Enums

ButtonStyle
The visual style applied to an inline or reply keyboard button.
MenuButton
Menu button configuration.
ReplyMarkup
All reply markup variants.