pub struct InlineKeyboardButton {Show 13 fields
pub text: String,
pub icon_custom_emoji_id: Option<String>,
pub style: Option<ButtonStyle>,
pub url: Option<String>,
pub callback_data: Option<String>,
pub web_app: Option<WebAppInfo>,
pub login_url: Option<LoginUrl>,
pub switch_inline_query: Option<String>,
pub switch_inline_query_current_chat: Option<String>,
pub switch_inline_query_chosen_chat: Option<SwitchInlineQueryChosenChat>,
pub copy_text: Option<CopyTextButton>,
pub callback_game: Option<Value>,
pub pay: Option<bool>,
}Expand description
One button in an inline keyboard.
Fields
text: StringLabel text on the button.
icon_custom_emoji_id: Option<String>Custom emoji identifier shown before the button text.
style: Option<ButtonStyle>Visual style of the button ("danger", "success", or "primary").
url: Option<String>URL to open when the button is pressed.
callback_data: Option<String>Data to be sent in a callback query (1–64 bytes).
web_app: Option<WebAppInfo>Web App to launch when the button is pressed.
login_url: Option<LoginUrl>Defines an authentication button.
switch_inline_query: Option<String>Pressing the button prompts the user to select a chat and opens an inline query.
switch_inline_query_current_chat: Option<String>Pressing the button opens an inline query in the current chat.
switch_inline_query_chosen_chat: Option<SwitchInlineQueryChosenChat>Prompts the user to select a specific type of chat for an inline query.
copy_text: Option<CopyTextButton>Describes a button that copies specified text to the clipboard.
callback_game: Option<Value>Description of the game that will be launched when the user presses the button.
pay: Option<bool>Specify true to send a Pay button (invoices only).
Implementations