pub struct KeyboardButtonRequestChat {
pub request_id: i32,
pub chat_is_channel: bool,
pub chat_is_forum: Option<bool>,
pub chat_has_username: Option<bool>,
pub chat_is_created: Option<bool>,
pub user_administrator_rights: Option<Value>,
pub bot_administrator_rights: Option<Value>,
pub bot_is_member: Option<bool>,
pub request_title: Option<bool>,
pub request_username: Option<bool>,
pub request_photo: Option<bool>,
}Expand description
Defines criteria for selecting a chat via a keyboard button.
Fields
request_id: i32Signed 32-bit identifier of the request.
chat_is_channel: booltrue to request a channel chat; false for group or supergroup.
chat_is_forum: Option<bool>true to request a forum supergroup.
chat_has_username: Option<bool>true to request a chat with a username.
chat_is_created: Option<bool>true to request a chat owned by the user.
user_administrator_rights: Option<Value>Required administrator rights of the user in the chat.
bot_administrator_rights: Option<Value>Required administrator rights of the bot in the chat.
bot_is_member: Option<bool>true to request a chat where the bot is a member.
request_title: Option<bool>true to request the chat title.
request_username: Option<bool>true to request the chat username.
request_photo: Option<bool>true to request the chat photo.