pub struct KeyboardButtonRequestManagedBot {
pub request_id: i32,
pub suggested_name: Option<String>,
pub suggested_username: Option<String>,
}Expand description
Defines parameters for requesting the creation of a managed bot.
Bot API 9.6 — available for bots that have enabled managed bot creation in @BotFather.
Fields
request_id: i32Signed 32-bit identifier of the request; must be unique within the message.
suggested_name: Option<String>Suggested name for the new bot.
suggested_username: Option<String>Suggested username for the new bot.