pub struct LoginUrl {
pub url: String,
pub forward_text: Option<String>,
pub bot_username: Option<String>,
pub request_write_access: Option<bool>,
}Expand description
Parameters for a Login URL button.
Fields
url: StringHTTPS URL to forward the user to.
forward_text: Option<String>New text of the button in forwarded messages.
bot_username: Option<String>Username of the bot to use for user authorization.
request_write_access: Option<bool>true to request permission for the bot to send messages to the user.