pub struct SwitchInlineQueryChosenChat {
pub query: Option<String>,
pub allow_user_chats: Option<bool>,
pub allow_bot_chats: Option<bool>,
pub allow_group_chats: Option<bool>,
pub allow_channel_chats: Option<bool>,
}Expand description
Parameters for inline query routing to a specific type of chat.
Fields
query: Option<String>Default inline query to insert in the input field.
allow_user_chats: Option<bool>true if private chats with users can be chosen.
allow_bot_chats: Option<bool>true if private chats with bots can be chosen.
allow_group_chats: Option<bool>true if group and supergroup chats can be chosen.
allow_channel_chats: Option<bool>true if channel chats can be chosen.