pub enum MessageEntityKind {
Show 20 variants
Mention,
Hashtag,
Cashtag,
BotCommand,
Url,
Email,
PhoneNumber,
Bold,
Italic,
Underline,
Strikethrough,
Spoiler,
Blockquote,
ExpandableBlockquote,
Code,
Pre,
TextLink,
TextMention,
CustomEmoji,
DateTime,
}Expand description
Type of a message entity.
Variants
Mention
@username mention.
Hashtag
#hashtag.
Cashtag
$cashtag.
BotCommand
/bot_command.
Url
Plain URL.
Email address.
PhoneNumber
Phone number.
Bold
Bold text.
Italic
Italic text.
Underline
Underlined text.
Strikethrough
Strikethrough text.
Spoiler
||Spoiler|| text.
Blockquote
Block quotation.
ExpandableBlockquote
An “expandable” block quotation that can be expanded to show the full text.
Code
Monospaced text.
Pre
Monospaced block.
TextLink
A text link. The url field will contain the destination URL.
TextMention
A text mention of a user. The user field will contain the mentioned user.
CustomEmoji
Custom emoji. The custom_emoji_id field will contain the identifier of the custom emoji.
DateTime
Date/time entity.