#[non_exhaustive]pub struct InaccessibleMessage {
pub chat: Chat,
pub message_id: i64,
pub date: i64,
}Expand description
A message that is no longer accessible to the bot.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.chat: ChatChat the message belonged to.
message_id: i64Unique message identifier inside the chat.
date: i64Always 0. This is the field that marks the message inaccessible.