pub struct LinkPreviewOptions {
pub is_disabled: Option<bool>,
pub url: Option<String>,
pub prefer_small_media: Option<bool>,
pub prefer_large_media: Option<bool>,
pub show_above_text: Option<bool>,
}Expand description
Options for controlling how links are previewed in messages.
Fields
is_disabled: Option<bool>true if link preview is disabled.
url: Option<String>URL to use for the link preview.
prefer_small_media: Option<bool>true if the media in the link preview should be shrunk.
prefer_large_media: Option<bool>true if the media in the link preview should be enlarged.
show_above_text: Option<bool>true if the link preview should be shown above the message text.