ReplyParameters

Struct ReplyParameters 

pub struct ReplyParameters {
    pub message_id: Option<i64>,
    pub ephemeral_message_id: Option<i64>,
    pub chat_id: Option<ChatId>,
    pub allow_sending_without_reply: Option<bool>,
    pub quote: Option<String>,
    pub quote_parse_mode: Option<ParseMode>,
    pub quote_entities: Option<Vec<MessageEntity>>,
    pub quote_position: Option<u32>,
    pub poll_option_id: Option<String>,
    pub checklist_task_id: Option<i64>,
}
Parameters for replying to a message.

Fields

message_id: Option<i64>

Identifier of the message that will be replied to in the current chat, or in the chat chat_id if specified. Required if ephemeral_message_id isn’t specified.

ephemeral_message_id: Option<i64>

Identifier of the ephemeral message that will be replied to in the current chat. A reply to an ephemeral message must itself be an ephemeral message. Required if message_id isn’t specified.

chat_id: Option<ChatId>

If the message to be replied to is from a different chat, the chat containing it. Not supported for messages sent on behalf of a business account, direct-messages-chat messages, or ephemeral messages.

allow_sending_without_reply: Option<bool>

true if the message should be sent even if the specified message is not found. Always false for replies in another chat or forum topic and for sent ephemeral messages. Always true for messages sent on behalf of a business account.

quote: Option<String>

Quoted part of the message to be replied to; 0–1024 characters after entities parsing. Must be an exact substring of the message being replied to, including any bold/italic/underline/strikethrough/spoiler/ custom_emoji/date_time entities. Ignored for ephemeral messages.

quote_parse_mode: Option<ParseMode>

Parse mode for the quote.

quote_entities: Option<Vec<MessageEntity>>

Special entities in the quote.

quote_position: Option<u32>

Position of the quote in the original message (UTF-16 offset).

poll_option_id: Option<String>

Identifier of the poll option being replied to.

checklist_task_id: Option<i64>

Identifier of the checklist task being replied to.