pub struct TextQuote {
pub text: String,
pub entities: Option<Vec<MessageEntity>>,
pub position: u32,
pub is_manual: Option<bool>,
}Expand description
Information about the quoted part of a message that is replied to.
Fields
text: StringText of the quoted part of the message.
entities: Option<Vec<MessageEntity>>Special entities in the quote.
position: u32Approximate quote position in the original message (UTF-16 offset).
is_manual: Option<bool>true if the quote was chosen manually by the message sender.