pub struct EncryptedPassportElement {
pub kind: String,
pub data: Option<String>,
pub phone_number: Option<String>,
pub email: Option<String>,
pub files: Option<Vec<PassportFile>>,
pub front_side: Option<PassportFile>,
pub reverse_side: Option<PassportFile>,
pub selfie: Option<PassportFile>,
pub translation: Option<Vec<PassportFile>>,
pub hash: String,
}Expand description
An encrypted element containing Telegram Passport data.
Fields
kind: StringElement type (e.g. "passport", "email", "phone_number").
data: Option<String>Base64-encoded encrypted Telegram Passport element data.
phone_number: Option<String>User’s verified phone number.
email: Option<String>User’s verified email address.
files: Option<Vec<PassportFile>>Array of encrypted files with documents.
front_side: Option<PassportFile>Encrypted file with the front side of the document.
reverse_side: Option<PassportFile>Encrypted file with the reverse side of the document.
selfie: Option<PassportFile>Encrypted file with a selfie of the user holding the document.
translation: Option<Vec<PassportFile>>Array of encrypted files with translated versions of the document.
hash: StringBase64-encoded element hash for error validation.