pub struct AcceptedGiftTypes {
pub unlimited_gifts: bool,
pub limited_gifts: bool,
pub unique_gifts: bool,
pub premium_subscription: bool,
pub gifts_from_channels: bool,
}Expand description
Types of gifts that can be gifted to a user or chat.
Fields
unlimited_gifts: booltrue if unlimited regular gifts are accepted.
limited_gifts: booltrue if limited regular gifts are accepted.
unique_gifts: booltrue if unique gifts or gifts upgradable to unique for free are accepted.
true if a Telegram Premium subscription is accepted.
gifts_from_channels: booltrue if transfers of unique gifts from channels are accepted.