pub struct AffiliateInfo {
pub affiliate_user: Option<User>,
pub affiliate_chat: Option<Chat>,
pub commission_per_mille: i64,
pub amount: i64,
pub nanostar_amount: Option<i32>,
}Expand description
Information about the affiliate that received a commission via this transaction.
Fields
affiliate_user: Option<User>The bot or user that received the affiliate commission, if applicable.
affiliate_chat: Option<Chat>The chat that received the affiliate commission, if applicable.
commission_per_mille: i64Stars received per 1000 Stars received by the affiliate program sponsor.
amount: i64Integer amount of Stars received from the transaction; can be negative for refunds.
nanostar_amount: Option<i32>Fractional nanostar amount; from -999,999,999 to 999,999,999.