pub struct OwnedGiftRegular {Show 14 fields
pub gift: Gift,
pub owned_gift_id: Option<String>,
pub sender_user: Option<User>,
pub send_date: i64,
pub text: Option<String>,
pub entities: Option<Vec<MessageEntity>>,
pub is_private: Option<bool>,
pub is_saved: Option<bool>,
pub can_be_upgraded: Option<bool>,
pub was_refunded: Option<bool>,
pub convert_star_count: Option<i64>,
pub prepaid_upgrade_star_count: Option<i64>,
pub is_upgrade_separate: Option<bool>,
pub unique_gift_number: Option<i64>,
}Expand description
A regular gift owned by a user or chat.
Fields
gift: GiftInformation about the regular gift.
owned_gift_id: Option<String>Unique identifier of the gift for the bot; for business account gifts only.
sender_user: Option<User>Sender of the gift if it is a known user.
send_date: i64Date the gift was sent, as a Unix timestamp.
text: Option<String>Text of the message added to the gift.
entities: Option<Vec<MessageEntity>>Special entities in the text.
is_private: Option<bool>true if only the gift receiver can see the sender and text.
is_saved: Option<bool>true if the gift is displayed on the account’s profile page.
can_be_upgraded: Option<bool>true if the gift can be upgraded to a unique gift.
was_refunded: Option<bool>true if the gift was refunded and is no longer available.
convert_star_count: Option<i64>Stars that can be claimed instead of the gift.
prepaid_upgrade_star_count: Option<i64>Stars prepaid for the ability to upgrade the gift.
is_upgrade_separate: Option<bool>true if the upgrade was purchased after the gift was sent.
unique_gift_number: Option<i64>Unique number reserved for this gift when upgraded.