pub struct OwnedGiftUnique {
pub gift: UniqueGift,
pub owned_gift_id: Option<String>,
pub sender_user: Option<User>,
pub send_date: i64,
pub is_saved: Option<bool>,
pub can_be_transferred: Option<bool>,
pub transfer_star_count: Option<i64>,
pub next_transfer_date: Option<i64>,
}Expand description
A unique gift owned by a user or chat.
Fields
gift: UniqueGiftInformation about the unique gift.
owned_gift_id: Option<String>Unique identifier of the gift for the bot; for business account gifts only.
sender_user: Option<User>Sender of the gift if it is a known user.
send_date: i64Date the gift was sent, as a Unix timestamp.
is_saved: Option<bool>true if the gift is displayed on the account’s profile page.
can_be_transferred: Option<bool>true if the gift can be transferred to another owner.
transfer_star_count: Option<i64>Stars required to transfer the gift.
next_transfer_date: Option<i64>Unix timestamp when the gift can next be transferred.