pub struct OwnedGifts {
pub total_count: i64,
pub gifts: Vec<OwnedGift>,
pub next_offset: Option<String>,
}Expand description
A paginated list of gifts owned by a user or chat.
Fields
total_count: i64Total number of gifts owned by the user or chat.
gifts: Vec<OwnedGift>The list of gifts.
next_offset: Option<String>Offset for the next request; absent if there are no more results.