pub struct PaidMediaPreview {
pub width: Option<i64>,
pub height: Option<i64>,
pub duration: Option<i64>,
}Expand description
A preview shown before a user purchases paid media.
Fields
width: Option<i64>Media width as defined by the sender.
height: Option<i64>Media height as defined by the sender.
duration: Option<i64>Duration of the media in seconds as defined by the sender.