pub struct TransactionPartnerAffiliateProgram {
pub sponsor_user: Option<User>,
pub commission_per_mille: i64,
}Expand description
The affiliate program that issued the commission received via this transaction.
Fields
sponsor_user: Option<User>The bot that sponsored the affiliate program, if applicable.
commission_per_mille: i64Stars received by the bot per 1000 Stars received by the program sponsor.