Poll types.
Structs
- Input
Poll Option - An option to include when creating a poll with
sendPoll. - Poll
- A native Telegram poll or quiz.
- Poll
Answer - An answer submitted by a user in a non-anonymous poll.
- Poll
Media - Media attached to a poll description, quiz explanation, or poll option.
- Poll
Option - One option in a
Poll. - Poll
Option Added - Service message: a new option was added to a poll.
- Poll
Option Deleted - Service message: an option was deleted from a poll.
Enums
- Input
Poll Media - Media content for a poll description or quiz explanation to be sent.
- Input
Poll Option Media - Media content for a poll option to be sent.
- Poll
Type - The type of a poll.