PollMedia

Struct PollMedia 

pub struct PollMedia {
    pub animation: Option<Animation>,
    pub audio: Option<Audio>,
    pub document: Option<Document>,
    pub live_photo: Option<LivePhoto>,
    pub location: Option<Location>,
    pub photo: Option<Vec<PhotoSize>>,
    pub sticker: Option<Sticker>,
    pub venue: Option<Venue>,
    pub video: Option<Video>,
}
Media attached to a poll description, quiz explanation, or poll option.

At most one of the optional fields will be Some.

Fields

animation: Option<Animation>

Animation media.

audio: Option<Audio>

Audio file; currently not receivable in poll options.

document: Option<Document>

General file; currently not receivable in poll options.

live_photo: Option<LivePhoto>

Live photo media.

location: Option<Location>

Location media.

photo: Option<Vec<PhotoSize>>

Photo media (available sizes).

sticker: Option<Sticker>

Sticker media; only for poll options.

venue: Option<Venue>

Venue media.

video: Option<Video>

Video media.