Module shared

Module shared 

Users and chats shared with the bot via keyboard request buttons.

Structs

ChatShared
Service message: a chat was shared with the bot.
SharedUser
A user shared with the bot via a KeyboardButtonRequestUsers button.
UsersShared
Service message: users were shared with the bot.