pub struct MaskPosition {
pub point: MaskPoint,
pub x_shift: f64,
pub y_shift: f64,
pub scale: f64,
}Expand description
The position of a mask sticker on a face.
Fields
point: MaskPointThe part of the face where the mask is placed.
x_shift: f64Shift by X-axis measured in widths of the mask, scaled to the face size.
y_shift: f64Shift by Y-axis measured in heights of the mask, scaled to the face size.
scale: f64Mask scaling coefficient.