pub struct Sticker {Show 15 fields
pub file_id: String,
pub file_unique_id: String,
pub kind: StickerType,
pub width: u32,
pub height: u32,
pub is_animated: bool,
pub is_video: bool,
pub thumbnail: Option<PhotoSize>,
pub emoji: Option<String>,
pub set_name: Option<String>,
pub premium_animation: Option<File>,
pub mask_position: Option<MaskPosition>,
pub custom_emoji_id: Option<String>,
pub needs_repainting: Option<bool>,
pub file_size: Option<u64>,
}Expand description
A Telegram sticker.
Fields
file_id: StringTelegram file identifier.
file_unique_id: StringUnique file identifier, stable across bots and time.
kind: StickerTypeSticker type.
width: u32Sticker width in pixels.
height: u32Sticker height in pixels.
is_animated: booltrue if the sticker is animated (TGS format).
is_video: booltrue if the sticker is a video sticker (WEBM format).
thumbnail: Option<PhotoSize>Sticker thumbnail.
emoji: Option<String>Emoji associated with the sticker.
set_name: Option<String>Name of the sticker set this sticker belongs to.
Premium animation for the sticker.
mask_position: Option<MaskPosition>Mask position for mask stickers.
custom_emoji_id: Option<String>Custom emoji identifier for custom emoji stickers.
needs_repainting: Option<bool>true if the sticker must be repainted to a text color in messages.
file_size: Option<u64>File size in bytes.