Module update

Module update 

Update and event types.

Structs

BusinessBotRights
Represents the rights of a business bot.
BusinessConnection
A business connection was established or removed.
BusinessMessagesDeleted
Business messages that were deleted.
CallbackQuery
Incoming callback query from a callback button in an inline keyboard.
ChatBoost
Information about a chat boost.
ChatBoostAdded
Service message: the chat was boosted.
ChatBoostRemoved
A boost was removed from a chat.
ChatBoostSourceGiftCode
A boost obtained by the creation of Telegram Premium gift codes.
ChatBoostSourceGiveaway
A boost obtained by the creation of a giveaway.
ChatBoostSourcePremium
A boost obtained by subscribing to Telegram Premium or gifting it.
ChatBoostUpdated
A boost was added or changed in a chat.
ChatMemberUpdated
A chat member’s status change.
ManagedBotUpdated
A managed bot was connected or disconnected.
MessageReactionCountUpdated
Anonymous reactions to a message were changed.
MessageReactionUpdated
A reaction to a message changed by a user.
PaidMediaPurchased
Purchased paid media.
ReactionCount
Count of a specific reaction type.
Update
An incoming update from Telegram.
UserChatBoosts
A list of boosts added to a chat by a user.

Enums

ChatBoostSource
How a chat boost was obtained.
UpdateKind
The specific kind of an incoming update.