pub enum ChatBoostSource {
Premium(ChatBoostSourcePremium),
GiftCode(ChatBoostSourceGiftCode),
Giveaway(ChatBoostSourceGiveaway),
}Expand description
How a chat boost was obtained.
Variants
Premium(ChatBoostSourcePremium)
The boost was obtained by subscribing to Telegram Premium or gifting it.
GiftCode(ChatBoostSourceGiftCode)
The boost was obtained by the creation of Telegram Premium gift codes.
Giveaway(ChatBoostSourceGiveaway)
The boost was obtained by the creation of a Telegram Premium or Star giveaway.