pub struct BusinessBotRights {Show 14 fields
pub can_reply: Option<bool>,
pub can_read_messages: Option<bool>,
pub can_delete_sent_messages: Option<bool>,
pub can_delete_all_messages: Option<bool>,
pub can_edit_name: Option<bool>,
pub can_edit_bio: Option<bool>,
pub can_edit_profile_photo: Option<bool>,
pub can_edit_username: Option<bool>,
pub can_change_gift_settings: Option<bool>,
pub can_view_gifts_and_stars: Option<bool>,
pub can_convert_gifts_to_stars: Option<bool>,
pub can_transfer_and_upgrade_gifts: Option<bool>,
pub can_transfer_stars: Option<bool>,
pub can_manage_stories: Option<bool>,
}Expand description
Represents the rights of a business bot.
All fields are optional — a missing field means the right is not granted.
Fields
can_reply: Option<bool>true if the bot can send and edit messages in private chats that had
incoming messages in the last 24 hours.
can_read_messages: Option<bool>true if the bot can mark incoming private messages as read.
can_delete_sent_messages: Option<bool>true if the bot can delete messages sent by the bot.
can_delete_all_messages: Option<bool>true if the bot can delete all private messages in managed chats.
can_edit_name: Option<bool>true if the bot can edit the first and last name of the business account.
can_edit_bio: Option<bool>true if the bot can edit the bio of the business account.
can_edit_profile_photo: Option<bool>true if the bot can edit the profile photo of the business account.
can_edit_username: Option<bool>true if the bot can edit the username of the business account.
can_change_gift_settings: Option<bool>true if the bot can change gift privacy settings for the business account.
can_view_gifts_and_stars: Option<bool>true if the bot can view gifts and the Telegram Stars balance of the business account.
can_convert_gifts_to_stars: Option<bool>true if the bot can convert regular gifts owned by the business account to Telegram Stars.
can_transfer_and_upgrade_gifts: Option<bool>true if the bot can transfer and upgrade gifts owned by the business account.
can_transfer_stars: Option<bool>true if the bot can transfer Telegram Stars received by the business account.
can_manage_stories: Option<bool>true if the bot can post, edit, and delete stories on behalf of the business account.