pub struct BusinessConnection {
pub id: String,
pub user: User,
pub user_chat_id: i64,
pub date: i64,
pub can_reply: bool,
pub is_enabled: bool,
pub rights: Option<Value>,
}Expand description
A business connection was established or removed.
Fields
id: StringUnique identifier of the business connection.
user: UserThe business account user.
user_chat_id: i64Identifier of the private chat with the user.
date: i64Date the connection was established as a Unix timestamp.
can_reply: booltrue if the bot can act on behalf of the business account.
is_enabled: booltrue if the connection is active.
rights: Option<Value>Rights of the bot in the business account.