pub struct CallbackQuery {
pub id: String,
pub from: User,
pub message: Option<Message>,
pub inline_message_id: Option<String>,
pub chat_instance: String,
pub data: Option<String>,
pub game_short_name: Option<String>,
}Expand description
Incoming callback query from a callback button in an inline keyboard.
Fields
id: StringUnique identifier for this query.
from: UserUser who sent the query.
message: Option<Message>Message sent by the bot with the button that originated the query.
inline_message_id: Option<String>Identifier of the message sent via the bot in inline mode.
chat_instance: StringGlobal identifier, uniquely corresponding to the chat where the query originated.
data: Option<String>Data associated with the callback button.
game_short_name: Option<String>Short name of a Game to be returned.