#[non_exhaustive]pub struct ChatBoostSourceGiveaway {
pub giveaway_message_id: i64,
pub user: Option<User>,
pub prize_star_count: Option<i64>,
pub is_unclaimed: Option<bool>,
}Expand description
A boost obtained by the creation of a giveaway.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.giveaway_message_id: i64Identifier of the message with the giveaway in the chat.
user: Option<User>User that won the prize in the giveaway, if any.
prize_star_count: Option<i64>Number of Telegram Stars to be split among winners; Star giveaways only.
is_unclaimed: Option<bool>true if the giveaway was completed but no user won the prize.