pub struct UserChatBoosts {
pub boosts: Vec<ChatBoost>,
}Expand description
A list of boosts added to a chat by a user.
Returned by getUserChatBoosts.
Fields
boosts: Vec<ChatBoost>The list of boosts added to the chat by the user.