pub enum BotCommandScope {
Default,
AllPrivateChats,
AllGroupChats,
AllChatAdministrators,
Chat {
chat_id: ChatId,
},
ChatAdministrators {
chat_id: ChatId,
},
ChatMember {
chat_id: ChatId,
user_id: i64,
},
}Expand description
Bot command scope — defines where a specific list of commands applies.
Variants
Default
Default scope — used when no more specific scope is applicable.
AllPrivateChats
Covers all private chats.
AllGroupChats
Covers all group and supergroup chats.
AllChatAdministrators
Covers all group and supergroup chat administrators.
Chat
Covers a specific chat.
ChatAdministrators
Covers all administrators of a specific group or supergroup.
ChatMember
Covers a specific member of a group or supergroup.