pub struct BotAccessSettings {
pub is_access_restricted: bool,
pub added_users: Option<Vec<User>>,
}Expand description
Describes the access settings of a bot.
Returned by getManagedBotAccessSettings.
Fields
is_access_restricted: booltrue if only selected users can access the bot. The bot’s owner can always access it.
added_users: Option<Vec<User>>The list of other users who have access to the bot if the access is restricted.