pub struct WebhookInfo {
pub url: String,
pub has_custom_certificate: bool,
pub pending_update_count: u32,
pub ip_address: Option<String>,
pub last_error_date: Option<i64>,
pub last_error_message: Option<String>,
pub last_synchronization_error_date: Option<i64>,
pub max_connections: Option<u32>,
pub allowed_updates: Option<Vec<String>>,
}Expand description
Current status of a registered webhook.
Returned by getWebhookInfo.
Check last_error_message and last_error_date to diagnose delivery
failures.
Fields
url: StringWebhook URL.
has_custom_certificate: booltrue if a custom certificate was provided for the webhook.
pending_update_count: u32Number of updates awaiting delivery.
ip_address: Option<String>Currently used webhook IP address.
last_error_date: Option<i64>Unix timestamp of the most recent error when delivering updates.
last_error_message: Option<String>Description of the most recent delivery error.
last_synchronization_error_date: Option<i64>Unix timestamp of the most recent error when synchronising with the webhook.
max_connections: Option<u32>Maximum allowed number of simultaneous HTTPS connections to the webhook.
allowed_updates: Option<Vec<String>>List of update types the bot is subscribed to.