Chat background types.
Structs
- Background
Fill Freeform Gradient - A background filled with a freeform gradient that rotates after every message.
- Background
Fill Gradient - A background filled with a two-colour gradient.
- Background
Fill Solid - A background filled with a single colour.
- Background
Type Chat Theme - A background taken from one of the default chat themes.
- Background
Type Fill - A background automatically filled based on colours.
- Background
Type Pattern - A background that is a PNG or TGV pattern filled with a colour.
- Background
Type Wallpaper - A background that is a wallpaper image in JPEG format.
- Chat
Background - A chat background.
Enums
- Background
Fill - How a chat background is filled with colour.
- Background
Type - The type of a chat background.