pub struct Chat {
pub id: i64,
pub kind: ChatType,
pub title: Option<String>,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub is_forum: Option<bool>,
pub is_direct_messages: Option<bool>,
pub guard_bot: Option<User>,
}Expand description
Minimal chat descriptor — used in messages and updates.
Fields
id: i64Unique identifier for this chat.
kind: ChatTypeType of chat.
title: Option<String>Title, for supergroups, channels and group chats.
username: Option<String>Username, for private chats, supergroups and channels.
first_name: Option<String>First name of the other party in a private chat.
last_name: Option<String>Last name of the other party in a private chat.
is_forum: Option<bool>true if the supergroup chat is a forum (has topics enabled).
is_direct_messages: Option<bool>true if the chat is the direct messages chat of a channel.
guard_bot: Option<User>The bot that processes join request queries in the chat.
Only available to chat administrators.
Implementations