#[non_exhaustive]pub struct ChatFullInfo {Show 53 fields
pub id: i64,
pub kind: ChatType,
pub title: Option<String>,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub is_forum: Option<bool>,
pub is_direct_messages: Option<bool>,
pub accent_color_id: u32,
pub max_reaction_count: u32,
pub guard_bot: Option<User>,
pub birthdate: Option<Birthdate>,
pub business_intro: Option<BusinessIntro>,
pub business_location: Option<BusinessLocation>,
pub business_opening_hours: Option<BusinessOpeningHours>,
pub personal_chat: Option<Box<Chat>>,
pub parent_chat: Option<Box<Chat>>,
pub available_reactions: Option<Vec<ReactionType>>,
pub background_custom_emoji_id: Option<String>,
pub profile_accent_color_id: Option<u32>,
pub profile_background_custom_emoji_id: Option<String>,
pub emoji_status_custom_emoji_id: Option<String>,
pub emoji_status_expiration_date: Option<i64>,
pub accepted_gift_types: AcceptedGiftTypes,
pub rating: Option<UserRating>,
pub first_profile_audio: Option<Audio>,
pub unique_gift_colors: Option<UniqueGiftColors>,
pub paid_message_star_count: Option<i64>,
pub photo: Option<ChatPhoto>,
pub active_usernames: Option<Vec<String>>,
pub bio: Option<String>,
pub has_private_forwards: Option<bool>,
pub has_restricted_voice_and_video_messages: Option<bool>,
pub join_to_send_messages: Option<bool>,
pub join_by_request: Option<bool>,
pub description: Option<String>,
pub invite_link: Option<String>,
pub pinned_message: Option<Box<Message>>,
pub permissions: Option<ChatPermissions>,
pub can_send_paid_media: Option<bool>,
pub slow_mode_delay: Option<u32>,
pub unrestrict_boost_count: Option<u32>,
pub message_auto_delete_time: Option<u32>,
pub has_aggressive_anti_spam_enabled: Option<bool>,
pub has_hidden_members: Option<bool>,
pub has_protected_content: Option<bool>,
pub has_visible_history: Option<bool>,
pub sticker_set_name: Option<String>,
pub can_set_sticker_set: Option<bool>,
pub custom_emoji_sticker_set_name: Option<String>,
pub linked_chat_id: Option<i64>,
pub location: Option<ChatLocation>,
pub community: Option<Community>,
}Expand description
Full chat information — returned by getChat.
#[non_exhaustive] for the same reason as Chat — this is the
fastest-growing object in the Bot API.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: i64Unique identifier for this chat.
kind: ChatTypeType of chat.
title: Option<String>Title of the chat (groups, supergroups, and channels).
username: Option<String>Username of the chat.
first_name: Option<String>First name of the other party in a private chat.
last_name: Option<String>Last name of the other party in a private chat.
is_forum: Option<bool>true if the supergroup chat is a forum (has topics enabled).
is_direct_messages: Option<bool>true if the chat is the direct messages chat of a channel.
accent_color_id: u32Identifier of the accent color for the chat name and backgrounds.
Required by the spec, but kept defaulted rather than bare so that a response from an older Bot API server still decodes.
max_reaction_count: u32Maximum number of reactions that can be set on a message.
guard_bot: Option<User>The bot that processes join request queries in the chat.
Only available to chat administrators.
birthdate: Option<Birthdate>Birthdate of a private chat’s user.
business_intro: Option<BusinessIntro>Intro of a private chat with a business account.
business_location: Option<BusinessLocation>Location of a private chat with a business account.
business_opening_hours: Option<BusinessOpeningHours>Opening hours of a private chat with a business account.
personal_chat: Option<Box<Chat>>The personal channel of a private chat’s user.
parent_chat: Option<Box<Chat>>The chat this direct messages chat belongs to.
available_reactions: Option<Vec<ReactionType>>Reactions allowed in the chat. Absent means every emoji reaction is allowed.
background_custom_emoji_id: Option<String>Custom emoji identifier of the emoji chosen by the chat for its reply header and link preview background.
profile_accent_color_id: Option<u32>Identifier of the accent color for the chat’s profile background.
profile_background_custom_emoji_id: Option<String>Custom emoji identifier of the emoji chosen by the chat for its profile background.
emoji_status_custom_emoji_id: Option<String>Custom emoji identifier of the emoji status of the chat or the user.
emoji_status_expiration_date: Option<i64>Expiration date of the emoji status, as a Unix timestamp.
accepted_gift_types: AcceptedGiftTypesTypes of gifts accepted by the chat.
rating: Option<UserRating>Rating of a private chat’s user.
first_profile_audio: Option<Audio>The audio shown first on the user’s profile.
unique_gift_colors: Option<UniqueGiftColors>Colour scheme used for the chat’s name, replies, and link previews, taken from a unique gift.
paid_message_star_count: Option<i64>Number of Telegram Stars a user must pay to send one message to the chat.
photo: Option<ChatPhoto>Chat photo.
active_usernames: Option<Vec<String>>Active usernames of a channel, supergroup, or user.
bio: Option<String>Bio of the other party in a private chat.
has_private_forwards: Option<bool>true if privacy settings prevent viewing the other party’s bio.
has_restricted_voice_and_video_messages: Option<bool>true if the privacy settings prevent sending voice and video note messages.
join_to_send_messages: Option<bool>true if users need to join in order to send messages.
join_by_request: Option<bool>true if all users directly joining the supergroup need to be approved.
description: Option<String>Description, for groups, supergroups and channel chats.
invite_link: Option<String>Primary invite link for the chat.
pinned_message: Option<Box<Message>>Latest pinned message.
permissions: Option<ChatPermissions>Default chat member permissions, for groups and supergroups.
can_send_paid_media: Option<bool>true if paid media messages can be sent or forwarded to the channel chat.
slow_mode_delay: Option<u32>Delay in seconds between consecutive messages from a non-administrator.
unrestrict_boost_count: Option<u32>Delay in seconds after which all messages sent by the user will be automatically deleted.
message_auto_delete_time: Option<u32>Message auto-delete timer setting for new messages.
has_aggressive_anti_spam_enabled: Option<bool>true if aggressive anti-spam checks are enabled in the supergroup.
true if non-administrators can only get the list of bots and administrators.
has_protected_content: Option<bool>true if messages from the chat can’t be forwarded to other chats.
has_visible_history: Option<bool>true if new chat members will have access to old messages.
sticker_set_name: Option<String>Name of the group sticker set.
can_set_sticker_set: Option<bool>true if the bot can change the group sticker set.
custom_emoji_sticker_set_name: Option<String>Custom emoji identifier of the emoji chosen by the chat for the reply header.
linked_chat_id: Option<i64>Unique identifier for the linked chat.
location: Option<ChatLocation>The location to which the supergroup is connected.
community: Option<Community>The Community to which the chat belongs.