pub struct ChatFullInfo {Show 35 fields
pub id: i64,
pub kind: ChatType,
pub title: Option<String>,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub is_forum: Option<bool>,
pub is_direct_messages: Option<bool>,
pub accent_color_id: Option<u32>,
pub max_reaction_count: Option<u32>,
pub photo: Option<ChatPhoto>,
pub active_usernames: Option<Vec<String>>,
pub bio: Option<String>,
pub has_private_forwards: Option<bool>,
pub has_restricted_voice_and_video_messages: Option<bool>,
pub join_to_send_messages: Option<bool>,
pub join_by_request: Option<bool>,
pub description: Option<String>,
pub invite_link: Option<String>,
pub pinned_message: Option<Box<Message>>,
pub permissions: Option<ChatPermissions>,
pub can_send_paid_media: Option<bool>,
pub slow_mode_delay: Option<u32>,
pub unrestrict_boost_count: Option<u32>,
pub message_auto_delete_time: Option<u32>,
pub has_aggressive_anti_spam_enabled: Option<bool>,
pub has_hidden_members: Option<bool>,
pub has_protected_content: Option<bool>,
pub has_visible_history: Option<bool>,
pub sticker_set_name: Option<String>,
pub can_set_sticker_set: Option<bool>,
pub custom_emoji_sticker_set_name: Option<String>,
pub linked_chat_id: Option<i64>,
pub location: Option<ChatLocation>,
pub community: Option<Community>,
}Expand description
Full chat information — returned by getChat.
Fields
id: i64Unique identifier for this chat.
kind: ChatTypeType of chat.
title: Option<String>Title of the chat (groups, supergroups, and channels).
username: Option<String>Username of the chat.
first_name: Option<String>First name of the other party in a private chat.
last_name: Option<String>Last name of the other party in a private chat.
is_forum: Option<bool>true if the supergroup chat is a forum (has topics enabled).
is_direct_messages: Option<bool>true if the chat is the direct messages chat of a channel.
accent_color_id: Option<u32>Identifier of the accent color for the chat name and backgrounds.
max_reaction_count: Option<u32>Maximum number of reactions that can be set on a message.
photo: Option<ChatPhoto>Chat photo.
active_usernames: Option<Vec<String>>Active usernames of a channel, supergroup, or user.
bio: Option<String>Bio of the other party in a private chat.
has_private_forwards: Option<bool>true if privacy settings prevent viewing the other party’s bio.
has_restricted_voice_and_video_messages: Option<bool>true if the privacy settings prevent sending voice and video note messages.
join_to_send_messages: Option<bool>true if users need to join in order to send messages.
join_by_request: Option<bool>true if all users directly joining the supergroup need to be approved.
description: Option<String>Description, for groups, supergroups and channel chats.
invite_link: Option<String>Primary invite link for the chat.
pinned_message: Option<Box<Message>>Latest pinned message.
permissions: Option<ChatPermissions>Default chat member permissions, for groups and supergroups.
can_send_paid_media: Option<bool>true if paid media messages can be sent or forwarded to the channel chat.
slow_mode_delay: Option<u32>Delay in seconds between consecutive messages from a non-administrator.
unrestrict_boost_count: Option<u32>Delay in seconds after which all messages sent by the user will be automatically deleted.
message_auto_delete_time: Option<u32>Message auto-delete timer setting for new messages.
has_aggressive_anti_spam_enabled: Option<bool>true if aggressive anti-spam checks are enabled in the supergroup.
true if non-administrators can only get the list of bots and administrators.
has_protected_content: Option<bool>true if messages from the chat can’t be forwarded to other chats.
has_visible_history: Option<bool>true if new chat members will have access to old messages.
sticker_set_name: Option<String>Name of the group sticker set.
can_set_sticker_set: Option<bool>true if the bot can change the group sticker set.
custom_emoji_sticker_set_name: Option<String>Custom emoji identifier of the emoji chosen by the chat for the reply header.
linked_chat_id: Option<i64>Unique identifier for the linked chat.
location: Option<ChatLocation>The location to which the supergroup is connected.
community: Option<Community>The Community to which the chat belongs.