Checklist content type and related service messages.
Structs
- Checklist
- A checklist message content type.
- Checklist
Task - A single task in a checklist.
- Checklist
Tasks Added - Service message: new tasks were added to a checklist.
- Checklist
Tasks Done - Service message: tasks in a checklist were marked as done or not done.
- Input
Checklist - A checklist to send or create.
- Input
Checklist Task - A task to add when creating or editing a checklist.