pub struct Gift {Show 13 fields
pub id: String,
pub sticker: Sticker,
pub star_count: u32,
pub upgrade_star_count: Option<u32>,
pub is_premium: Option<bool>,
pub has_colors: Option<bool>,
pub total_count: Option<u32>,
pub remaining_count: Option<u32>,
pub personal_total_count: Option<u32>,
pub personal_remaining_count: Option<u32>,
pub background: Option<GiftBackground>,
pub unique_gift_variant_count: Option<u32>,
pub publisher_chat: Option<Chat>,
}Expand description
A Telegram gift that can be sent to users.
Retrieve available gifts with getAvailableGifts.
Fields
id: StringUnique gift identifier.
sticker: StickerThe sticker that represents this gift.
star_count: u32Number of Telegram Stars that must be paid to send this gift.
upgrade_star_count: Option<u32>Number of Telegram Stars required to upgrade this gift to a unique gift.
true if the gift can only be purchased by Telegram Premium subscribers.
has_colors: Option<bool>true if the gift can be used to customize a user’s appearance after upgrading.
total_count: Option<u32>Total number of gifts of this type that can be sent; absent if unlimited.
remaining_count: Option<u32>Number of remaining gifts of this type available to all users.
personal_total_count: Option<u32>Total number of gifts of this type the bot can send; for limited gifts only.
personal_remaining_count: Option<u32>Number of remaining gifts of this type the bot can send; for limited gifts only.
background: Option<GiftBackground>Background of the gift.
unique_gift_variant_count: Option<u32>Total number of unique gift variants obtainable by upgrading this gift.
publisher_chat: Option<Chat>Information about the chat that published the gift.