Module inline

Module inline 

Inline query and result types.

Structs

ChosenInlineResult
The result a user chose from an inline query.
InlineQuery
An incoming inline query sent when a user types @YourBot something in any chat.
InlineQueryResultArticle
A link to an article or web page.
InlineQueryResultAudio
A link to an audio file (.mp3 or .m4a).
InlineQueryResultCachedAudio
An audio file from a previously uploaded Telegram file.
InlineQueryResultCachedDocument
A document from a previously uploaded Telegram file.
InlineQueryResultCachedGif
An animated GIF from a previously uploaded Telegram file.
InlineQueryResultCachedMpeg4Gif
An MPEG4 animation from a previously uploaded Telegram file.
InlineQueryResultCachedPhoto
A photo from a previously uploaded Telegram file.
InlineQueryResultCachedSticker
A sticker from a previously uploaded Telegram file.
InlineQueryResultCachedVideo
A video from a previously uploaded Telegram file.
InlineQueryResultCachedVoice
A voice message from a previously uploaded Telegram file.
InlineQueryResultContact
A contact with a phone number.
InlineQueryResultDocument
A link to a general file (application/pdf or application/zip).
InlineQueryResultGame
A game result.
InlineQueryResultGif
A link to an animated GIF file (max 1 MB).
InlineQueryResultLocation
A geographic location on a map.
InlineQueryResultMpeg4Gif
A link to a video animation (MPEG4 without sound, max 1 MB).
InlineQueryResultPhoto
A link to a photo (JPEG, max 5 MB). A photo result in an inline query.
InlineQueryResultVenue
A venue.
InlineQueryResultVideo
A link to a video file (text/html or video/mp4).
InlineQueryResultVoice
A link to a voice recording in .ogg format encoded with OPUS.
InlineQueryResultsButton
A button shown above inline query results.
InputContactMessageContent
A contact message to send as an inline query result.
InputInvoiceMessageContent
An invoice message to send as an inline query result.
InputLocationMessageContent
A live location message to send as an inline query result.
InputTextMessageContent
A text message to send as an inline query result.
InputVenueMessageContent
A venue message to send as an inline query result.
PreparedInlineMessage
An inline message prepared for sending by a Mini App.
SentGuestMessage
An inline message sent by a guest bot.
SentWebAppMessage
A message sent from a Web App on behalf of the user.

Enums

InlineQueryResult
One result to show in an inline query answer.
InputMessageContent
The content of a message sent as the result of an inline query.