Inline query and result types.
Structs
- Chosen
Inline Result - The result a user chose from an inline query.
- Inline
Query - An incoming inline query sent when a user types
@YourBot somethingin any chat. - Inline
Query Result Article - A link to an article or web page.
- Inline
Query Result Audio - A link to an audio file (
.mp3or.m4a). - Inline
Query Result Cached Audio - An audio file from a previously uploaded Telegram file.
- Inline
Query Result Cached Document - A document from a previously uploaded Telegram file.
- Inline
Query Result Cached Gif - An animated GIF from a previously uploaded Telegram file.
- Inline
Query Result Cached Mpeg4 Gif - An MPEG4 animation from a previously uploaded Telegram file.
- Inline
Query Result Cached Photo - A photo from a previously uploaded Telegram file.
- Inline
Query Result Cached Sticker - A sticker from a previously uploaded Telegram file.
- Inline
Query Result Cached Video - A video from a previously uploaded Telegram file.
- Inline
Query Result Cached Voice - A voice message from a previously uploaded Telegram file.
- Inline
Query Result Contact - A contact with a phone number.
- Inline
Query Result Document - A link to a general file (
application/pdforapplication/zip). - Inline
Query Result Game - A game result.
- Inline
Query Result Gif - A link to an animated GIF file (max 1 MB).
- Inline
Query Result Location - A geographic location on a map.
- Inline
Query Result Mpeg4 Gif - A link to a video animation (MPEG4 without sound, max 1 MB).
- Inline
Query Result Photo - A link to a photo (JPEG, max 5 MB). A photo result in an inline query.
- Inline
Query Result Venue - A venue.
- Inline
Query Result Video - A link to a video file (
text/htmlorvideo/mp4). - Inline
Query Result Voice - A link to a voice recording in
.oggformat encoded with OPUS. - Input
Contact Message Content - A contact message to send as an inline query result.
- Input
Invoice Message Content - An invoice message to send as an inline query result.
- Input
Location Message Content - A live location message to send as an inline query result.
- Input
Text Message Content - A text message to send as an inline query result.
- Input
Venue Message Content - A venue message to send as an inline query result.
- Sent
Guest Message - An inline message sent by a guest bot.
- Sent
WebApp Message - A message sent from a Web App on behalf of the user.
Enums
- Inline
Query Result - One result to show in an inline query answer.
- Input
Message Content - The content of a message to be sent as the result of an inline query. The content of a message sent as the result of an inline query.