InlineQueryResult

Enum InlineQueryResult 

pub enum InlineQueryResult {
Show 20 variants Article(InlineQueryResultArticle), Photo(InlineQueryResultPhoto), Gif(InlineQueryResultGif), Mpeg4Gif(InlineQueryResultMpeg4Gif), Video(InlineQueryResultVideo), Audio(InlineQueryResultAudio), Voice(InlineQueryResultVoice), Document(InlineQueryResultDocument), Location(InlineQueryResultLocation), Venue(InlineQueryResultVenue), Contact(InlineQueryResultContact), Game(InlineQueryResultGame), CachedPhoto(InlineQueryResultCachedPhoto), CachedGif(InlineQueryResultCachedGif), CachedMpeg4Gif(InlineQueryResultCachedMpeg4Gif), CachedSticker(InlineQueryResultCachedSticker), CachedDocument(InlineQueryResultCachedDocument), CachedVideo(InlineQueryResultCachedVideo), CachedVoice(InlineQueryResultCachedVoice), CachedAudio(InlineQueryResultCachedAudio),
}
One result to show in an inline query answer.

Up to 50 results can be returned per answerInlineQuery call. Each variant corresponds to a different content type (article, photo, video, etc.). Cached variants re-use a previously uploaded Telegram file_id rather than a URL.

Variants



Article(InlineQueryResultArticle)

A link to an article or web page.



Photo(InlineQueryResultPhoto)

A link to a photo.



Gif(InlineQueryResultGif)

A link to an animated GIF.



Mpeg4Gif(InlineQueryResultMpeg4Gif)

A link to a video animation (MPEG4 without sound).



Video(InlineQueryResultVideo)

A link to a video.



Audio(InlineQueryResultAudio)

A link to an audio file.



Voice(InlineQueryResultVoice)

A link to a voice recording.



Document(InlineQueryResultDocument)

A link to a general file.



Location(InlineQueryResultLocation)

A geographic location.



Venue(InlineQueryResultVenue)

A venue.



Contact(InlineQueryResultContact)

A contact.



Game(InlineQueryResultGame)

A game.



CachedPhoto(InlineQueryResultCachedPhoto)

A photo from a Telegram file_id.



CachedGif(InlineQueryResultCachedGif)

A GIF from a Telegram file_id.



CachedMpeg4Gif(InlineQueryResultCachedMpeg4Gif)

An MPEG4 GIF from a Telegram file_id.



CachedSticker(InlineQueryResultCachedSticker)

A sticker from a Telegram file_id.



CachedDocument(InlineQueryResultCachedDocument)

A document from a Telegram file_id.



CachedVideo(InlineQueryResultCachedVideo)

A video from a Telegram file_id.



CachedVoice(InlineQueryResultCachedVoice)

A voice message from a Telegram file_id.



CachedAudio(InlineQueryResultCachedAudio)

An audio file from a Telegram file_id.