InputMessageContent

Enum InputMessageContent 

pub enum InputMessageContent {
    Text(InputTextMessageContent),
    Rich(InputRichMessageContent),
    Location(InputLocationMessageContent),
    Venue(InputVenueMessageContent),
    Contact(InputContactMessageContent),
    Invoice(InputInvoiceMessageContent),
}
The content of a message to be sent as the result of an inline query. The content of a message sent as the result of an inline query.

Variants



Text(InputTextMessageContent)

The message text.



Rich(InputRichMessageContent)

A rich formatted message.



Location(InputLocationMessageContent)

A location on a map.



Venue(InputVenueMessageContent)

A venue.



Contact(InputContactMessageContent)

A contact.



Invoice(InputInvoiceMessageContent)

An invoice.