pub struct InlineQueryResultCachedMpeg4Gif {
pub id: String,
pub mpeg4_file_id: String,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub show_caption_above_media: Option<bool>,
}Expand description
An MPEG4 GIF result using a previously uploaded Telegram file_id.
Fields
id: StringUnique identifier for this result (1–64 bytes).
mpeg4_file_id: StringA valid Telegram file_id of the cached media.
title: Option<String>Title for the result.
caption: Option<String>Caption of the media (0–1024 characters).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the media.
show_caption_above_media: Option<bool>Show the caption above the media instead of below.