pub struct InlineQueryResultGif {
pub id: String,
pub gif_url: String,
pub thumbnail_url: String,
pub gif_width: Option<u32>,
pub gif_height: Option<u32>,
pub gif_duration: Option<u32>,
pub title: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub show_caption_above_media: Option<bool>,
}Expand description
An animated GIF result in an inline query.
Fields
id: StringUnique identifier for this result (1–64 bytes).
gif_url: StringA valid URL for the GIF file (max 1 MB).
thumbnail_url: StringURL of the static or animated thumbnail for the result.
gif_width: Option<u32>Width of the GIF in pixels.
gif_height: Option<u32>Height of the GIF in pixels.
gif_duration: Option<u32>Duration of the GIF in seconds.
title: Option<String>Title for the result.
caption: Option<String>Caption of the media (0–1024 characters).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the media.
show_caption_above_media: Option<bool>Show the caption above the media instead of below.