pub struct InlineQueryResultPhoto {
pub id: String,
pub photo_url: String,
pub thumbnail_url: String,
pub photo_width: Option<u32>,
pub photo_height: Option<u32>,
pub title: Option<String>,
pub description: Option<String>,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub show_caption_above_media: Option<bool>,
}Expand description
A photo result in an inline query.
Fields
id: StringUnique identifier for this result (1–64 bytes).
photo_url: StringA valid URL of the photo (JPEG, max 5 MB).
thumbnail_url: StringURL of the thumbnail for the photo.
photo_width: Option<u32>Photo width in pixels.
photo_height: Option<u32>Photo height in pixels.
title: Option<String>Title for the result.
description: Option<String>Short description of the result.
caption: Option<String>Caption of the media (0–1024 characters).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the media.
show_caption_above_media: Option<bool>Show the caption above the media instead of below.