pub struct InlineQueryResultVideo {Show 14 fields
pub id: String,
pub video_url: String,
pub mime_type: String,
pub thumbnail_url: String,
pub title: String,
pub caption: Option<String>,
pub parse_mode: Option<ParseMode>,
pub video_width: Option<u32>,
pub video_height: Option<u32>,
pub video_duration: Option<u32>,
pub description: Option<String>,
pub reply_markup: Option<InlineKeyboardMarkup>,
pub input_message_content: Option<InputMessageContent>,
pub show_caption_above_media: Option<bool>,
}Expand description
A video result in an inline query.
Fields
id: StringUnique identifier for this result (1–64 bytes).
video_url: StringA valid URL for the video file.
mime_type: StringMIME type of the video (text/html or video/mp4).
thumbnail_url: StringURL of the thumbnail for the video.
title: StringTitle for the result.
caption: Option<String>Caption of the media (0–1024 characters).
parse_mode: Option<ParseMode>Parse mode for the caption. See formatting options for more details.
video_width: Option<u32>Video width in pixels.
video_height: Option<u32>Video height in pixels.
video_duration: Option<u32>Video duration in seconds.
description: Option<String>Short description of the result.
reply_markup: Option<InlineKeyboardMarkup>Inline keyboard attached to the message.
input_message_content: Option<InputMessageContent>Content of the message to be sent instead of the media.
show_caption_above_media: Option<bool>Show the caption above the media instead of below.