InputInvoiceMessageContent

Struct InputInvoiceMessageContent 

pub struct InputInvoiceMessageContent {
Show 20 fields pub title: String, pub description: String, pub payload: String, pub provider_token: Option<String>, pub currency: String, pub prices: Vec<LabeledPrice>, pub max_tip_amount: Option<u64>, pub suggested_tip_amounts: Option<Vec<u64>>, pub provider_data: Option<String>, pub photo_url: Option<String>, pub photo_size: Option<u64>, pub photo_width: Option<u32>, pub photo_height: Option<u32>, pub need_name: Option<bool>, pub need_phone_number: Option<bool>, pub need_email: Option<bool>, pub need_shipping_address: Option<bool>, pub send_phone_number_to_provider: Option<bool>, pub send_email_to_provider: Option<bool>, pub is_flexible: Option<bool>,
}
An invoice message to send as an inline query result.

Fields

title: String

Product name (1–32 characters).

description: String

Product description (1–255 characters).

payload: String

Bot-defined invoice payload (1–128 bytes).

provider_token: Option<String>

Payment provider token; not required for Telegram Stars.

currency: String

Three-letter ISO 4217 currency code.

prices: Vec<LabeledPrice>

Price breakdown as a list of labeled portions.

max_tip_amount: Option<u64>

Maximum accepted tip amount in the smallest currency unit.

suggested_tip_amounts: Option<Vec<u64>>

Suggested tip amounts in the smallest currency unit.

provider_data: Option<String>

JSON-encoded data about the invoice for the payment provider.

photo_url: Option<String>

URL of the product photo.

photo_size: Option<u64>

Photo size in bytes.

photo_width: Option<u32>

Photo width in pixels.

photo_height: Option<u32>

Photo height in pixels.

need_name: Option<bool>

Requests the buyer’s full name.

need_phone_number: Option<bool>

Requests the buyer’s phone number.

need_email: Option<bool>

Requests the buyer’s email address.

need_shipping_address: Option<bool>

Requests the buyer’s shipping address.

send_phone_number_to_provider: Option<bool>

Passes the buyer’s phone number to the payment provider.

send_email_to_provider: Option<bool>

Passes the buyer’s email address to the payment provider.

is_flexible: Option<bool>

true if the final price depends on the shipping method.