Keyboard and markup types.
Structs
- Copy
Text Button - Represents a button that copies text to clipboard.
- Force
Reply - Forces a reply from the user.
- Inline
Keyboard Button - One button in an inline keyboard.
- Inline
Keyboard Markup - An inline keyboard attached to a message.
- Keyboard
Button - One button in a reply keyboard.
- Keyboard
Button Poll Type - The type of poll requested via a keyboard button.
- Keyboard
Button Request Chat - Defines criteria for selecting a chat via a keyboard button.
- Keyboard
Button Request Managed Bot - Defines parameters for requesting the creation of a managed bot.
- Keyboard
Button Request Users - Defines criteria for selecting users via a keyboard button.
- Login
Url - Parameters for a Login URL button.
- Prepared
Keyboard Button - A keyboard button prepared for use by a Mini App.
- Reply
Keyboard Markup - Custom keyboard shown to the message recipient.
- Reply
Keyboard Remove - Instructs clients to remove the reply keyboard.
- Switch
Inline Query Chosen Chat - Parameters for inline query routing to a specific type of chat.
Enums
- Button
Style - The visual style applied to an inline or reply keyboard button.
- Menu
Button - Menu button configuration.
- Reply
Markup - All reply markup variants.