Module message

Module message 

Message and entity types.

Structs

ChatOwnerChanged
Service message: ownership of the chat changed (Bot API 9.4).
ChatOwnerLeft
Service message: the chat owner left the chat (Bot API 9.4).
Contact
Phone contact.
Dice
Animated dice with a random value.
ExternalReplyInfo
Information about a message that is being replied to from outside the thread.
LinkPreviewOptions
Options for controlling how links are previewed in messages.
Message
A Telegram message.
MessageEntity
One special entity in a message text.
MessageId
Lightweight message identifier returned by copyMessage.
ReplyParameters
Parameters for replying to a message.
TextQuote
Information about the quoted part of a message that is replied to.
WebAppData
Data sent from a Web App.
WebAppInfo
Information about a Web App.

Enums

MessageEntityKind
Type of a message entity.
MessageOrigin
Origin of a forwarded message.
ParseMode
Text parse mode for message formatting.
ReactionType
Reaction type on a message.