Message and entity types.
Structs
- Chat
Owner Changed - Service message: ownership of the chat changed (Bot API 9.4).
- Chat
Owner Left - Service message: the chat owner left the chat (Bot API 9.4).
- Contact
- Phone contact.
- Dice
- Animated dice with a random value.
- External
Reply Info - Information about a message that is being replied to from outside the thread.
- Link
Preview Options - Options for controlling how links are previewed in messages.
- Message
- A Telegram message.
- Message
Entity - One special entity in a message text.
- Message
Id - Lightweight message identifier returned by
copyMessage. - Reply
Parameters - Parameters for replying to a message.
- Text
Quote - Information about the quoted part of a message that is replied to.
- WebApp
Data - Data sent from a Web App.
- WebApp
Info - Information about a Web App.
Enums
- Message
Entity Kind - Type of a message entity.
- Message
Origin - Origin of a forwarded message.
- Parse
Mode - Text parse mode for message formatting.
- Reaction
Type - Reaction type on a message.