ExternalReplyInfo

Struct ExternalReplyInfo 

pub struct ExternalReplyInfo {
Show 20 fields pub origin: MessageOrigin, pub chat: Option<Chat>, pub message_id: Option<i64>, pub link_preview_options: Option<LinkPreviewOptions>, pub animation: Option<Animation>, pub audio: Option<Audio>, pub document: Option<Document>, pub photo: Option<Vec<PhotoSize>>, pub live_photo: Option<LivePhoto>, pub sticker: Option<Sticker>, pub video: Option<Video>, pub video_note: Option<VideoNote>, pub voice: Option<Voice>, pub has_media_spoiler: Option<bool>, pub checklist: Option<Checklist>, pub contact: Option<Contact>, pub dice: Option<Dice>, pub location: Option<Location>, pub venue: Option<Venue>, pub poll: Option<Poll>,
}
Information about a message that is being replied to from outside the thread.

Fields

origin: MessageOrigin

Origin of the message being replied to.

chat: Option<Chat>

Chat the original message belongs to (if not the current chat).

message_id: Option<i64>

Identifier of the original message in the original chat.

link_preview_options: Option<LinkPreviewOptions>

Options for link preview.

animation: Option<Animation>

Animation in the original message.

audio: Option<Audio>

Audio in the original message.

document: Option<Document>

Document in the original message.

photo: Option<Vec<PhotoSize>>

Photo in the original message.

live_photo: Option<LivePhoto>

Live photo in the original message.

sticker: Option<Sticker>

Sticker in the original message.

video: Option<Video>

Video in the original message.

video_note: Option<VideoNote>

Video note in the original message.

voice: Option<Voice>

Voice note in the original message.

has_media_spoiler: Option<bool>

true if the media is covered by a spoiler animation.

checklist: Option<Checklist>

Checklist in the original message.

contact: Option<Contact>

Contact in the original message.

dice: Option<Dice>

Dice in the original message.

location: Option<Location>

Location in the original message.

venue: Option<Venue>

Venue in the original message.

poll: Option<Poll>

Poll in the original message.