pub struct ReplyParameters {
pub message_id: i64,
pub chat_id: Option<ChatId>,
pub allow_sending_without_reply: Option<bool>,
pub quote: Option<String>,
pub quote_parse_mode: Option<ParseMode>,
pub quote_entities: Option<Vec<MessageEntity>>,
pub quote_position: Option<u32>,
pub poll_option_id: Option<String>,
pub checklist_task_id: Option<i64>,
}Expand description
Parameters for replying to a message.
Fields
message_id: i64Identifier of the message that will be replied to.
chat_id: Option<ChatId>Chat containing the message.
allow_sending_without_reply: Option<bool>true if the message should be sent even if the specified message is not found.
quote: Option<String>Quoted part of the message to be replied to.
quote_parse_mode: Option<ParseMode>Parse mode for the quote.
quote_entities: Option<Vec<MessageEntity>>Special entities in the quote.
quote_position: Option<u32>Position of the quote in the original message (UTF-16 offset).
poll_option_id: Option<String>Identifier of the poll option being replied to.
checklist_task_id: Option<i64>Identifier of the checklist task being replied to.