Module payments

Module payments 

Payment and invoice types.

Structs

AcceptedGiftTypes
Types of gifts that can be gifted to a user or chat.
AffiliateInfo
Information about the affiliate that received a commission via this transaction.
BotSubscriptionUpdated
Information about changes to a user payment subscription toward the bot.
Invoice
An invoice for a payment inside a message.
LabeledPrice
A portion of a price — label and amount in the smallest currency unit.
OrderInfo
Information about an order collected from the user during checkout.
OwnedGiftRegular
A regular gift owned by a user or chat.
OwnedGiftUnique
A unique gift owned by a user or chat.
OwnedGifts
A paginated list of gifts owned by a user or chat.
PaidMediaInfo
Information about paid media attached to a message.
PaidMediaLivePhoto
A live photo available as paid media.
PaidMediaPhoto
A photo available as paid media.
PaidMediaPreview
A preview shown before a user purchases paid media.
PaidMediaVideo
A video available as paid media.
PreCheckoutQuery
An incoming pre-checkout query.
RefundedPayment
Information about a refunded payment.
ShippingAddress
A shipping address provided by the user during checkout.
ShippingOption
One shipping option offered to the user during payment.
ShippingQuery
An incoming shipping query from a user.
StarAmount
An amount of Telegram Stars.
StarTransaction
A single Telegram Star transaction.
StarTransactions
A list of Telegram Star transactions.
SuccessfulPayment
Confirmation that a payment was completed successfully.
TransactionPartnerAffiliateProgram
The affiliate program that issued the commission received via this transaction.
TransactionPartnerChat
A transaction with a chat.
TransactionPartnerFragment
A withdrawal transaction with Fragment.
TransactionPartnerTelegramApi
A transaction for paid broadcasting.
TransactionPartnerUser
A transaction with a user.

Enums

OwnedGift
A gift received and owned by a user or chat.
PaidMedia
One item of paid media.
RevenueWithdrawalState
The state of a revenue withdrawal operation.
TransactionPartner
The source or recipient of a Star transaction.