Payment and invoice types.
Structs
- Accepted
Gift Types - Types of gifts that can be gifted to a user or chat.
- Affiliate
Info - Information about the affiliate that received a commission via this transaction.
- BotSubscription
Updated - Information about changes to a user payment subscription toward the bot.
- Invoice
- An invoice for a payment inside a message.
- Labeled
Price - A portion of a price — label and amount in the smallest currency unit.
- Order
Info - Information about an order collected from the user during checkout.
- Owned
Gift Regular - A regular gift owned by a user or chat.
- Owned
Gift Unique - A unique gift owned by a user or chat.
- Owned
Gifts - A paginated list of gifts owned by a user or chat.
- Paid
Media Info - Information about paid media attached to a message.
- Paid
Media Live Photo - A live photo available as paid media.
- Paid
Media Photo - A photo available as paid media.
- Paid
Media Preview - A preview shown before a user purchases paid media.
- Paid
Media Video - A video available as paid media.
- PreCheckout
Query - An incoming pre-checkout query.
- Refunded
Payment - Information about a refunded payment.
- Shipping
Address - A shipping address provided by the user during checkout.
- Shipping
Option - One shipping option offered to the user during payment.
- Shipping
Query - An incoming shipping query from a user.
- Star
Amount - An amount of Telegram Stars.
- Star
Transaction - A single Telegram Star transaction.
- Star
Transactions - A list of Telegram Star transactions.
- Successful
Payment - Confirmation that a payment was completed successfully.
- Transaction
Partner Affiliate Program - The affiliate program that issued the commission received via this transaction.
- Transaction
Partner Chat - A transaction with a chat.
- Transaction
Partner Fragment - A withdrawal transaction with Fragment.
- Transaction
Partner Telegram Api - A transaction for paid broadcasting.
- Transaction
Partner User - A transaction with a user.
Enums
- Owned
Gift - A gift received and owned by a user or chat.
- Paid
Media - One item of paid media.
- Revenue
Withdrawal State - The state of a revenue withdrawal operation.
- Transaction
Partner - The source or recipient of a Star transaction.