Module poll

Module poll 

Poll types.

Structs

InputPollOption
An option to include when creating a poll with sendPoll.
Poll
A native Telegram poll or quiz.
PollAnswer
An answer submitted by a user in a non-anonymous poll.
PollMedia
Media attached to a poll description, quiz explanation, or poll option.
PollOption
One option in a Poll.
PollOptionAdded
Service message: a new option was added to a poll.
PollOptionDeleted
Service message: an option was deleted from a poll.

Enums

InputPollMedia
Media content for a poll description or quiz explanation to be sent.
InputPollOptionMedia
Media content for a poll option to be sent.
PollType
The type of a poll.