Rich message types (Bot API 10.1).
Structs
- Input
Rich Message - Describes a rich message to be sent.
- Input
Rich Message Content - Rich message content to be sent as the result of an inline / guest / Web App query.
- Rich
Block Anchor - An in-document anchor (
<a name="…"></a>). - Rich
Block Animation - A looping animation / GIF block (
<video loop>). - Rich
Block Audio - An audio file block (
<audio>). - Rich
Block Block Quotation - A block quotation (
<blockquote>). - Rich
Block Caption - Caption (and optional credit) for a media block.
- Rich
Block Collage - A multi-media collage (
<tg-collage>). - Rich
Block Details - A collapsible details / disclosure block (
<details>). - Rich
Block Divider - A horizontal rule / divider (
<hr/>). - Rich
Block Footer - A footer block (
<footer>). - Rich
Block List - An ordered or unordered list (
<ul>/<ol>). - Rich
Block List Item - A single item inside a
RichBlockList. - Rich
Block Map - An embedded map (
<tg-map>). - Rich
Block Mathematical Expression - A block-level mathematical expression in LaTeX format (
<tg-math-block>). - Rich
Block Paragraph - A text paragraph (
<p>). - Rich
Block Photo - A photo block (
<photo>). - Rich
Block Preformatted - A preformatted text block (
<pre><code>). - Rich
Block Pull Quotation - A pull quotation with centred text (
<aside>). - Rich
Block Section Heading - A section heading, corresponding to
<h1>…<h6>. - Rich
Block Slideshow - A media slideshow (
<tg-slideshow>). - Rich
Block Table - A table (
<table>). - Rich
Block Table Cell - A single cell inside a
RichBlockTable. - Rich
Block Thinking - A
Thinking…placeholder for use while a bot streams an AI response. - Rich
Block Video - A video block (
<video>). - Rich
Block Voice Note - A voice note block (
<audio>in voice-note context). - Rich
Message - A complete rich formatted message as received from the Bot API.
- Rich
Text Anchor - An in-document anchor definition (
<a name="id"></a>). - Rich
Text Anchor Link - A link to an in-document anchor (
<a href="#id">text</a>). - Rich
Text Bank Card Number - A bank card number.
- Rich
Text Bold - Bold text (
**text**/<b>text</b>). - Rich
Text BotCommand - A bot command (e.g.
/start). - Rich
Text Cashtag - A
$cashtag. - Rich
Text Code - Inline monospace/code text (
`text`/<code>text</code>). - Rich
Text Custom Emoji - A custom emoji (
). - Rich
Text Date Time - A date/time entity rendered according to the client’s locale.
- Rich
Text Email Address - An e-mail address link (
[text](mailto:addr)/<a href="mailto:addr">text</a>). - Rich
Text Footnote - The body of a footnote.
- Rich
Text Hashtag - A
#hashtag. - Rich
Text Italic - Italic text (
*text*/<i>text</i>). - Rich
Text Marked - Highlighted/marked text (
==text==/<mark>text</mark>). - Rich
Text Mathematical Expression - An inline LaTeX mathematical expression (
$expr$/<tg-math>expr</tg-math>). - Rich
Text Mention - A
@usernamemention. - Rich
Text Phone Number - A telephone number link (
[text](tel:+nnn)/<a href="tel:+nnn">text</a>). - Rich
Text Reference - A reference to a previously defined footnote.
- Rich
Text Spoiler - Spoiler text (
||text||/<tg-spoiler>text</tg-spoiler>). - Rich
Text Strikethrough - Strikethrough text (
~~text~~/<s>text</s>). - Rich
Text Subscript - Subscript text (
<sub>text</sub>). - Rich
Text Superscript - Superscript text (
<sup>text</sup>). - Rich
Text Text Mention - A mention of a Telegram user by their
Userobject. - Rich
Text Underline - Underlined text (
<u>text</u>). - Rich
Text Url - A hyperlink (
[text](url)/<a href="url">text</a>).