pub enum InputRichBlock {
Show 21 variants
Paragraph(InputRichBlockParagraph),
SectionHeading(InputRichBlockSectionHeading),
Preformatted(InputRichBlockPreformatted),
Footer(InputRichBlockFooter),
Divider(InputRichBlockDivider),
MathematicalExpression(InputRichBlockMathematicalExpression),
Anchor(InputRichBlockAnchor),
List(InputRichBlockList),
BlockQuotation(InputRichBlockBlockQuotation),
PullQuotation(InputRichBlockPullQuotation),
Collage(InputRichBlockCollage),
Slideshow(InputRichBlockSlideshow),
Table(InputRichBlockTable),
Details(InputRichBlockDetails),
Map(InputRichBlockMap),
Animation(InputRichBlockAnimation),
Audio(InputRichBlockAudio),
Photo(InputRichBlockPhoto),
Video(InputRichBlockVideo),
VoiceNote(InputRichBlockVoiceNote),
Thinking(InputRichBlockThinking),
}Expand description
A block in a rich formatted message to be sent.
This is the input-side counterpart to RichBlock — used to build
InputRichMessage::blocks rather than to read a received RichMessage.
Variants
Paragraph(InputRichBlockParagraph)
A text paragraph, corresponding to the HTML tag <p>.
SectionHeading(InputRichBlockSectionHeading)
A section heading, corresponding to the HTML tags <h1>…<h6>.
Preformatted(InputRichBlockPreformatted)
A preformatted text block, corresponding to the nested HTML tags <pre> and <code>.
A footer, corresponding to the HTML tag <footer>.
Divider(InputRichBlockDivider)
A divider, corresponding to the HTML tag <hr/>.
MathematicalExpression(InputRichBlockMathematicalExpression)
A block with a mathematical expression in LaTeX format, corresponding
to the custom HTML tag <tg-math-block>.
Anchor(InputRichBlockAnchor)
A block with an anchor, corresponding to the HTML tag <a> with the attribute name.
List(InputRichBlockList)
A list of blocks, corresponding to the HTML tag <ul> or <ol> with nested <li> tags.
BlockQuotation(InputRichBlockBlockQuotation)
A block quotation, corresponding to the HTML tag <blockquote>.
PullQuotation(InputRichBlockPullQuotation)
A quotation with centered text, loosely corresponding to the HTML tag <aside>.
Collage(InputRichBlockCollage)
A collage, corresponding to the custom HTML tag <tg-collage>.
Slideshow(InputRichBlockSlideshow)
A slideshow, corresponding to the custom HTML tag <tg-slideshow>.
Table(InputRichBlockTable)
A table, corresponding to the HTML tag <table>.
Details(InputRichBlockDetails)
An expandable block for details disclosure, corresponding to the HTML tag <details>.
Map(InputRichBlockMap)
A block with a map, corresponding to the custom HTML tag <tg-map>.
Animation(InputRichBlockAnimation)
A block with an animation, corresponding to the HTML tag <video>.
Audio(InputRichBlockAudio)
A block with a music file, corresponding to the HTML tag <audio>.
Photo(InputRichBlockPhoto)
A block with a photo, corresponding to the HTML tag <img>.
Video(InputRichBlockVideo)
A block with a video, corresponding to the HTML tag <video>.
VoiceNote(InputRichBlockVoiceNote)
A block with a voice note, corresponding to the HTML tag <audio>.
Thinking(InputRichBlockThinking)
A Thinking… placeholder, corresponding to the custom HTML tag <tg-thinking>.
May be used only in sendRichMessageDraft
calls — it cannot be received in messages. See https://t.me/addemoji/AIActions
for recommended custom emoji.