Module update

Module update 

Update and event types.

Structs

BusinessConnection
A business connection was established or removed.
BusinessMessagesDeleted
Business messages that were deleted.
CallbackQuery
Incoming callback query from a callback button in an inline keyboard.
ChatBoost
Information about a chat boost.
ChatBoostRemoved
A boost was removed from a chat.
ChatBoostUpdated
A boost was added or changed in a chat.
ChatMemberUpdated
A chat member’s status change.
ManagedBotUpdated
A managed bot was connected or disconnected.
MessageReactionCountUpdated
Anonymous reactions to a message were changed.
MessageReactionUpdated
A reaction to a message changed by a user.
PaidMediaPurchased
Purchased paid media.
ReactionCount
Count of a specific reaction type.
Update
An incoming update from Telegram.
Updates
A list of updates returned by getUpdates. Internal deserialization wrapper.

Enums

UpdateKind
The specific kind of an incoming update.