Module user

Module user 

User and bot command types.

Structs

BotCommand
Represents a bot command.
BotDescription
The bot’s description shown in the chat when the chat is empty.
BotName
The bot’s display name.
BotShortDescription
The bot’s short description shown on the profile page and in sharing links.
ChatAdministratorRights
Represents the rights of an administrator in a chat.
User
Represents a Telegram user or bot.
UserProfileAudios
Container for a user’s profile audios.
UserProfilePhotos
Container for a user’s profile photos.

Enums

BotCommandScope
Bot command scope — defines where a specific list of commands applies.
ChatId
Flexible chat identifier — either a numeric ID or a @username.