ChatAdministratorRights

Struct ChatAdministratorRights 

pub struct ChatAdministratorRights {
Show 17 fields pub is_anonymous: bool, pub can_manage_chat: bool, pub can_delete_messages: bool, pub can_manage_video_chats: bool, pub can_restrict_members: bool, pub can_promote_members: bool, pub can_change_info: bool, pub can_invite_users: bool, pub can_post_stories: bool, pub can_edit_stories: bool, pub can_delete_stories: bool, pub can_post_messages: Option<bool>, pub can_edit_messages: Option<bool>, pub can_pin_messages: Option<bool>, pub can_manage_topics: Option<bool>, pub can_manage_direct_messages: Option<bool>, pub can_manage_tags: Option<bool>,
}
Represents the rights of an administrator in a chat.

Used by setMyDefaultAdministratorRights and getMyDefaultAdministratorRights.

Fields

is_anonymous: bool

true if the user’s presence in the chat is hidden.

can_manage_chat: bool

true if the administrator can access the chat event log, boost list, etc.

can_delete_messages: bool

true if the administrator can delete messages of other users.

can_manage_video_chats: bool

true if the administrator can manage video chats.

can_restrict_members: bool

true if the administrator can restrict, ban, or unban chat members.

can_promote_members: bool

true if the administrator can promote members to administrators.

can_change_info: bool

true if the user is allowed to change the chat title, photo, and other settings.

can_invite_users: bool

true if the user is allowed to invite new users to the chat.

can_post_stories: bool

true if the administrator can post stories to the chat.

can_edit_stories: bool

true if the administrator can edit stories posted by other users.

can_delete_stories: bool

true if the administrator can delete stories posted by other users.

can_post_messages: Option<bool>

true if the administrator can post messages in the channel; channels only.

can_edit_messages: Option<bool>

true if the administrator can edit messages of other users and pin messages; channels only.

can_pin_messages: Option<bool>

true if the user is allowed to pin messages; groups and supergroups only.

can_manage_topics: Option<bool>

true if the user is allowed to create, rename, close, and reopen forum topics; supergroups only.

can_manage_direct_messages: Option<bool>

true if the administrator can manage direct messages and decline suggested posts; channels only.

can_manage_tags: Option<bool>

true if the administrator can edit the tags of regular members; groups and supergroups only.