pub struct User {Show 14 fields
pub id: i64,
pub is_bot: bool,
pub first_name: String,
pub last_name: Option<String>,
pub username: Option<String>,
pub language_code: Option<String>,
pub is_premium: Option<bool>,
pub added_to_attachment_menu: Option<bool>,
pub can_join_groups: Option<bool>,
pub can_read_all_group_messages: Option<bool>,
pub supports_inline_queries: Option<bool>,
pub can_connect_to_business: Option<bool>,
pub has_main_web_app: Option<bool>,
pub can_manage_bots: Option<bool>,
}Expand description
Represents a Telegram user or bot.
Fields
id: i64Unique identifier for this user or bot.
is_bot: booltrue if this user is a bot.
first_name: StringUser’s or bot’s first name.
last_name: Option<String>User’s or bot’s last name.
username: Option<String>User’s or bot’s username.
language_code: Option<String>IETF language tag of the user’s language.
true if this user is a Telegram Premium user.
true if this user added the bot to the attachment menu.
can_join_groups: Option<bool>Bots only — true if the bot can be invited to groups.
can_read_all_group_messages: Option<bool>Bots only — true if privacy mode is disabled for the bot.
supports_inline_queries: Option<bool>Bots only — true if the bot supports inline queries.
can_connect_to_business: Option<bool>Bots only — true if the bot can be connected to a Telegram Business account.
has_main_web_app: Option<bool>Bots only — true if the bot has a main Web App.
can_manage_bots: Option<bool>Bots only — true if the bot can manage other bots.
Implementations